@@ -1,17 +1,22 @@
 ;;; muse-init.el --- Initialize Emacs Muse
 
-;; Author: Michael Olson
+;; This file is part of Michael Olson's Emacs settings.
+
+;; The code in this file may be used, distributed, and modified
+;; without restriction.
+
+;; I use initsplit.el to separate customize settings on a per-project
+;; basis.
 
 ;; In order to see the scripts that I use to publish my website to a
 ;; remote webserver, check out
-;; http://www.mwolson.org/projects/SiteScripts.html.
+;; http://mwolson.org/projects/SiteScripts.html.
 
 ;;; Setup
 
 ;; Add to load path
-(when (fboundp 'debian-pkg-add-load-path-item)
-  (debian-pkg-add-load-path-item "/stuff/proj/emacs/muse/rel--3.02/lisp")
-  (debian-pkg-add-load-path-item "/stuff/proj/emacs/muse/rel--3.02/experimental"))
+(add-to-list 'load-path "/home/mwolson/proj/emacs/muse/master/lisp")
+(add-to-list 'load-path "/home/mwolson/proj/emacs/muse/master/experimental")
 
 ;; Initialize
 (require 'outline)       ; I like outline-style faces
@@ -22,6 +27,8 @@
 (require 'muse-docbook)  ; load DocBook publishing style
 (require 'muse-html)     ; load (X)HTML publishing style
 (require 'muse-latex)    ; load LaTeX/PDF publishing styles
+(require 'muse-latex2png) ; publish <latex> tags
+(require 'muse-project)  ; load support for projects
 (require 'muse-texinfo)  ; load Info publishing style
 (require 'muse-wiki)     ; load Wiki support
 (require 'muse-xml)      ; load XML support
@@ -32,60 +39,87 @@
 ;; Here is an example of making a customized version of your favorite
 ;; publisher.  All this does is run `my-muse-blosoxm-finalize' on the
 ;; published file immediately after saving it.
+(muse-derive-style "my-blosxom" "blosxom-xhtml"
+                   :final 'my-muse-blosxom-finalize)
 
-(unless (assoc "my-blosxom" muse-publishing-styles)
-  (muse-derive-style "my-blosxom" "blosxom-xhtml"
-                     :final 'my-muse-blosxom-finalize)
+;; This turns relative links into absolute links
+(muse-derive-style "my-pdf" "pdf"
+                   :before 'my-muse-pdf-prepare-buffer)
 
-  (muse-derive-style "my-pdf" "pdf"
-                     :before 'my-muse-pdf-prepare-buffer)
+;; This uses a different header and footer than normal
+(muse-derive-style "my-xhtml" "xhtml"
+                   :header "~/personal-site/muse/header.html"
+                   :footer "~/personal-site/muse/footer.html")
 
-  (muse-derive-style "my-xhtml" "xhtml"
-                     :header "~/personal-site/muse/header.html"
-                     :footer "~/personal-site/muse/footer.html"))
+;; Define a draft style which provides extra space between sections
+
+(defvar muse-latex-draft-markup-strings
+  '((chapter      . "\\bigskip\n\\bigskip\n\\chapter{")
+    (section      . "\\bigskip\n\\bigskip\n\\section{")
+    (subsection   . "\\bigskip\n\\bigskip\n\\subsection{")
+    (subsubsection . "\\bigskip\n\\bigskip\n\\subsubsection{"))
+  "Strings used for marking up Latex draft text.")
+
+(muse-derive-style "latex-draft" "latex"
+                   :strings 'muse-latex-draft-markup-strings)
+(muse-derive-style "pdf-draft" "latex-draft"
+                   :final   'muse-latex-pdf-generate
+                   :browser 'muse-latex-pdf-browse-file
+                   :link-suffix 'muse-latex-pdf-extension
+                   :osuffix 'muse-latex-pdf-extension)
 
 ;; Here is my master project listing.
 
 (setq muse-project-alist
       `(
-        ("Website" ("~/proj/wiki/web/"
+        ("Website" ("~/proj/wiki/web/" "~/proj/wiki/web/testdir/"
                     :force-publish ("WikiIndex")
                     :default "WelcomePage")
          (:base "my-xhtml"
+                :base-url "http://mwolson.org/web/"
+                :include "/web/[^/]+"
                 :path "~/personal-site/site/web")
+         (:base "my-xhtml"
+                :base-url "http://mwolson.org/web/"
+                :include "/testdir/[^/]+"
+                :path "~/personal-site/site/web/testdir")
          (:base "my-pdf"
+                :base-url "http://mwolson.org/web/"
                 :path "~/personal-site/site/web"
-                :include "/CurriculumVitae[^/]*$"))
+                :include "/\\(CurriculumVitae\\|BriefResume\\)[^/]*$"))
 
         ("Projects" ("~/proj/wiki/projects/"
-                     :force-publish ("WikiIndex")
+                     :force-publish ("WikiIndex" "MuseQuickStart")
                      :default "WelcomePage")
          (:base "my-xhtml"
+                :base-url "http://mwolson.org/projects/"
                 :path "~/personal-site/site/projects"))
 
         ("Blog" (,@(muse-project-alist-dirs "~/proj/wiki/blog")
                  :default "index")
-
          ;; Publish this directory and its subdirectories.  Arguments
          ;; are as follows.  The above `muse-project-alist-dirs' part
-         ;; is also needed, using Argument 1.
-         ;;
-         ;;  1. Source directory
-         ;;  2. Output directory
-         ;;  3. Publishing style
+         ;; is also needed.
+         ;;   1. Source directory
+         ;;   2. Output directory
+         ;;   3. Publishing style
+         ;;   remainder: Other things to put in every generated style
          ,@(muse-project-alist-styles "~/proj/wiki/blog"
                                       "~/personal-site/site/blog"
-                                      "my-blosxom"))
+                                      "my-blosxom"
+                                      :base-url "http://blog.mwolson.org/"))
 
         ("MyNotes" ("~/proj/wiki/notes/"
                     :force-publish ("index")
                     :default "index")
          (:base "xhtml"
+                :base-url "http://mwolson.org/notes/"
                 :path "~/personal-site/site/notes")
          (:base "my-pdf"
+                :base-url "http://mwolson.org/notes/"
                 :path "~/personal-site/site/notes"))
 
-        ("Private" ("~/Documents" "~/Documents/work-school"
+        ("Private" ("~/Documents"
                     :default "movielist")
          ,@(muse-project-alist-styles "~/Documents"
                                       "~/Documents"
@@ -97,6 +131,14 @@
                                       "~/personal-site/site/classes"
                                       "xhtml"))
 
+        ("MA453" ("~/proj/classes/ma453")
+         (:base "pdf"
+                :path "~/proj/classes/ma453"))
+
+        ("CS565" ("~/proj/classes/cs565")
+         (:base "pdf"
+                :path "~/proj/classes/cs565"))
+
         ("Plans" ("~/proj/wiki/plans/"
                   :default "TaskPool"
                   :major-mode planner-mode
@@ -107,14 +149,17 @@
 
 ;; Wiki settings
 (setq muse-wiki-interwiki-alist
-      '(("PlugWiki" . "http://plug.student-orgs.purdue.edu/wiki/")
-        ("TheEmacsWiki" . "http://www.emacswiki.org/cgi-bin/wiki/")
-        ("ArchWiki" . "http://wiki.gnuarch.org/")
+      '(("PlugWiki" . "http://wiki.purduelug.org/")
+        ("EmacsWiki" . "http://www.emacswiki.org/cgi-bin/wiki/")
+        ("ArchWiki" . "http://gnuarch.org/gnuarchwiki/")
         ;; abbreviations
         ("CERIAS" . "http://www.cerias.purdue.edu/")
-        ("Planner" . "http://www.plannerlove.com/")
+        ("PlannerMode" . "http://www.emacswiki.org/cgi-bin/wiki/PlannerMode")
+        ("RememberMode" . "http://www.emacswiki.org/cgi-bin/wiki/RememberMode")
         ("GP2X" . "http://www.gp2x.co.uk/")
-        ("PLUG" . "http://plug.student-orgs.purdue.edu/wiki/")))
+        ("UbuntuLinux" . "http://ubuntulinux.org/")
+        ("PLUG" . "http://purduelug.org/")
+        ("PAC" . "http://web.ics.purdue.edu/~pac/")))
 
 ;;; Functions
 
@@ -124,7 +169,7 @@
   (when str
     (save-match-data
       (if (string-match "\\`[/.]+" str)
-          (replace-match "http://www.mwolson.org/" nil t str)
+          (replace-match "http://mwolson.org/" nil t str)
         str))))
 
 ;; Make sure my interproject links become absolute when published in
@@ -139,11 +184,6 @@
   (let ((muse-current-project (muse-project project)))
     (call-interactively 'muse-project-find-file)))
 
-;; Determine whether we are publishing a certain kind of output
-(defsubst my-muse-format-p (format)
-  (let ((base (muse-get-keyword :base muse-publishing-current-style)))
-    (when base (string-match format base))))
-
 (defun my-muse-blosxom-finalize (file output-path target)
 ;;  (my-muse-prepare-entry-for-xanga output-path)
 ;; For now, do nothing.
@@ -164,13 +204,13 @@ If FILE is not specified, use the published version of the current file."
                                    (cddr (muse-project-of-file))))))))
   (save-match-data
     (muse-with-temp-buffer
-      (insert-file-contents file)
-      ;; Surround first line in <h3></h3>
+      (muse-insert-file-contents file)
+      ;; surround first line in <h3></h3>
       (goto-char (point-min))
       (insert "<h3>")
       (end-of-line)
       (insert "</h3>")
-      ;; Treat example regions properly
+      ;; treat example regions properly
       (let (beg end)
         (while (re-search-forward "<pre[^>]*>" nil t)
           (setq beg (match-end 0))
@@ -179,30 +219,56 @@ If FILE is not specified, use the published version of the current file."
                       (point)))
           (save-restriction
             (narrow-to-region beg end)
-            ;; Change spaces to &nbsp;
+            ;; change initial spaces to &nbsp;
             (goto-char (point-min))
             (while (re-search-forward "^ +" nil t)
               (replace-match (apply 'concat (make-list
                                              (length (match-string 0))
                                              "&nbsp;"))))
-            ;; Change newline to <br />
+            ;; change newline to <br />
             (goto-char (point-min))
             (while (re-search-forward "\n" nil t)
               (replace-match "<br />")))))
-      ;; Get rid of 2 spaces together and merge lines
+      ;; get rid of 2 spaces together and merge lines
       (goto-char (point-min))
       (while (re-search-forward (concat "[" muse-regexp-blank "\n]+") nil t)
         (replace-match " "))
-      ;; Remove trailing space
+      ;; remove trailing space
       (goto-char (point-min))
       (while (re-search-forward " *</p> *" nil t)
         (replace-match "</p>"))
-      ;; Make relative links work
+      ;; make relative links work
       (goto-char (point-min))
       (while (re-search-forward "href=\"[/.]+" nil t)
-        (replace-match "href=\"http://www.mwolson.org/" nil t))
-      ;; Copy entry to clipboard
-      (clipboard-kill-ring-save (point-min) (point-max)))))
+        (replace-match "href=\"http://mwolson.org/" nil t))
+      ;; copy entry to clipboard
+      (clipboard-kill-ring-save (point-min) (point-max))
+      (message "Copied blog entry to clipboard"))))
+
+;; Turn a word or phrase into a clickable Wikipedia link
+(defun my-muse-dictize (beg end)
+  (interactive "r")
+  (let* ((text (buffer-substring-no-properties beg end))
+         (link (concat "dict:" (replace-regexp-in-string " " "_" text t t))))
+    (delete-region beg end)
+    (insert "[[" link "][" text "]]")))
+
+(defun my-muse-surround-math (beg end)
+  (interactive "r")
+  (save-restriction
+    (narrow-to-region beg end)
+    (goto-char (point-min))
+    (insert "<math>")
+    (goto-char (point-max))
+    (insert "</math>")))
+
+(defun my-muse-cdotize-region (beg end)
+  (interactive "r")
+  (save-restriction
+    (narrow-to-region beg end)
+    (goto-char (point-min))
+    (while (re-search-forward " *\\* *" nil t)
+      (replace-match " \\\\cdot "))))
 
 ;;; Key customizations
 
@@ -211,6 +277,8 @@ If FILE is not specified, use the published version of the current file."
                              (my-muse-project-find-file "Blog")))
 (global-set-key "\C-cpi" #'(lambda () (interactive)
                              (my-muse-project-find-file "Private")))
+(global-set-key "\C-cpm" #'(lambda () (interactive)
+                             (my-muse-project-find-file "MA453")))
 (global-set-key "\C-cpn" #'(lambda () (interactive)
                              (my-muse-project-find-file "MyNotes")))
 (global-set-key "\C-cpp" #'(lambda () (interactive)
@@ -221,7 +289,10 @@ If FILE is not specified, use the published version of the current file."
                              (my-muse-project-find-file "Classes")))
 (global-set-key "\C-cpw" #'(lambda () (interactive)
                              (my-muse-project-find-file "Website")))
-(global-set-key "\C-cpx" 'my-muse-prepare-entry-for-xanga)
+(global-set-key "\C-cpC" #'my-muse-cdotize-region)
+(global-set-key "\C-cpM" #'my-muse-surround-math)
+(global-set-key "\C-cpW" #'my-muse-dictize)
+(global-set-key "\C-cpx" #'my-muse-prepare-entry-for-xanga)
 
 ;;; Custom variables
 
@@ -229,7 +300,7 @@ If FILE is not specified, use the published version of the current file."
  '(muse-blosxom-base-directory "~/proj/wiki/blog/")
  '(muse-colors-autogen-headings (quote outline))
  '(muse-colors-inline-image-method (quote muse-colors-use-publishing-directory))
- '(muse-file-extension "muse")
+ '(muse-completing-read-function (quote ido-completing-read))
  '(muse-html-charset-default "utf-8")
  '(muse-html-encoding-default (quote utf-8))
  '(muse-html-footer "~/personal-site/muse/generic-footer.html")
@@ -239,16 +310,16 @@ If FILE is not specified, use the published version of the current file."
 <link rel=\"stylesheet\" type=\"text/css\" charset=\"utf-8\" media=\"screen\" href=\"/screen.css\" />
 <link rel=\"stylesheet\" type=\"text/css\" charset=\"utf-8\" media=\"print\" href=\"/print.css\" />")
  '(muse-latex-header "~/personal-site/muse/header.tex")
- '(muse-mode-auto-p nil nil (muse-project))
- '(muse-mode-highlight-p t nil (muse-colors))
- '(muse-mode-hook (quote (muse-wiki-update-custom-values flyspell-mode footnote-mode)))
+ '(muse-mode-hook (quote (flyspell-mode footnote-mode)))
  '(muse-publish-comments-p t)
- '(muse-publish-desc-transforms (quote (muse-wiki-publish-pretty-title muse-wiki-publish-pretty-interwiki)))
+ '(muse-publish-desc-transforms (quote (muse-wiki-publish-pretty-title muse-wiki-publish-pretty-interwiki muse-publish-strip-URL)))
  '(muse-wiki-publish-small-title-words (quote ("the" "and" "at" "on" "of" "for" "in" "an" "a" "page")))
  '(muse-xhtml-footer "~/personal-site/muse/generic-footer.html")
- '(muse-xhtml-header "~/personal-site/muse/generic-header.html"))
+ '(muse-xhtml-header "~/personal-site/muse/generic-header.html")
+ '(muse-xhtml-style-sheet "<link rel=\"stylesheet\" type=\"text/css\" charset=\"utf-8\" media=\"all\" href=\"/common.css\" />
+<link rel=\"stylesheet\" type=\"text/css\" charset=\"utf-8\" media=\"screen\" href=\"/screen.css\" />
+<link rel=\"stylesheet\" type=\"text/css\" charset=\"utf-8\" media=\"print\" href=\"/print.css\" />"))
 (custom-set-faces
- '(muse-bad-link-face ((t (:foreground "DeepPink" :underline "DeepPink" :weight bold))))
- '(muse-link-face ((t (:foreground "blue" :underline "blue" :weight bold)))))
+ '(muse-bad-link ((t (:foreground "DeepPink" :underline "DeepPink" :weight bold)))))
 
 ;;; muse-init.el ends here
