@@ -2,17 +2,17 @@
 ;;
 ;;; Code:
 
-;;;### (autoloads nil "muse" "muse.el" (18037 27226))
+;;;### (autoloads nil "muse" "muse.el" (18127 40831))
 ;;; Generated autoloads from muse.el
  (add-to-list 'auto-mode-alist '("\\.muse\\'" . muse-mode-choose-mode))
 
 ;;;***
 
 ;;;### (autoloads (muse-colors-toggle-inline-images) "muse-colors"
-;;;;;;  "muse-colors.el" (18034 56696))
+;;;;;;  "muse-colors.el" (18120 28388))
 ;;; Generated autoloads from muse-colors.el
 
-(autoload (quote muse-colors-toggle-inline-images) "muse-colors" "\
+(autoload 'muse-colors-toggle-inline-images "muse-colors" "\
 Toggle display of inlined images on/off.
 
 \(fn)" t nil)
@@ -20,15 +20,15 @@ Toggle display of inlined images on/off.
 ;;;***
 
 ;;;### (autoloads (muse-import-docbook-files muse-import-docbook)
-;;;;;;  "muse-import-docbook" "muse-import-docbook.el" (18032 42352))
+;;;;;;  "muse-import-docbook" "muse-import-docbook.el" (18119 50971))
 ;;; Generated autoloads from muse-import-docbook.el
 
-(autoload (quote muse-import-docbook) "muse-import-docbook" "\
+(autoload 'muse-import-docbook "muse-import-docbook" "\
 Convert the Docbook buffer SRC to Muse, writing output in the DEST buffer.
 
 \(fn SRC DEST)" t nil)
 
-(autoload (quote muse-import-docbook-files) "muse-import-docbook" "\
+(autoload 'muse-import-docbook-files "muse-import-docbook" "\
 Convert the Docbook file SRC to Muse, writing output to the DEST file.
 
 \(fn SRC DEST)" t nil)
@@ -36,10 +36,10 @@ Convert the Docbook file SRC to Muse, writing output to the DEST file.
 ;;;***
 
 ;;;### (autoloads (muse-import-latex) "muse-import-latex" "muse-import-latex.el"
-;;;;;;  (18032 42360))
+;;;;;;  (18119 50971))
 ;;; Generated autoloads from muse-import-latex.el
 
-(autoload (quote muse-import-latex) "muse-import-latex" "\
+(autoload 'muse-import-latex "muse-import-latex" "\
 Not documented
 
 \(fn)" t nil)
@@ -47,10 +47,10 @@ Not documented
 ;;;***
 
 ;;;### (autoloads (muse-message-markup) "muse-message" "../experimental/muse-message.el"
-;;;;;;  (18032 42614))
+;;;;;;  (18119 50971))
 ;;; Generated autoloads from ../experimental/muse-message.el
 
-(autoload (quote muse-message-markup) "muse-message" "\
+(autoload 'muse-message-markup "muse-message" "\
 Markup a wiki-ish e-mail message as HTML alternative e-mail.
 This step is manual by default, to give the author a chance to review
 the results and ensure they are appropriate.
@@ -61,75 +61,75 @@ function to `message-send-hook'.
 
 ;;;***
 
-;;;### (autoloads (muse-insert-tag muse-index muse-find-backlinks
-;;;;;;  muse-search muse-search-with-command muse-what-changed muse-previous-reference
-;;;;;;  muse-next-reference muse-follow-name-at-point-other-window
-;;;;;;  muse-follow-name-at-point muse-browse-result muse-edit-link-at-point
-;;;;;;  muse-insert-relative-link-to-file muse-decrease-list-item-indentation
-;;;;;;  muse-increase-list-item-indentation muse-insert-list-item
-;;;;;;  muse-mode-choose-mode muse-mode) "muse-mode" "muse-mode.el"
-;;;;;;  (18035 7037))
+;;;### (autoloads (muse-list-edit-minor-mode muse-insert-tag muse-index
+;;;;;;  muse-find-backlinks muse-search muse-search-with-command
+;;;;;;  muse-what-changed muse-previous-reference muse-next-reference
+;;;;;;  muse-follow-name-at-point-other-window muse-follow-name-at-point
+;;;;;;  muse-browse-result muse-edit-link-at-point muse-insert-relative-link-to-file
+;;;;;;  muse-decrease-list-item-indentation muse-increase-list-item-indentation
+;;;;;;  muse-insert-list-item muse-mode-choose-mode muse-mode) "muse-mode"
+;;;;;;  "muse-mode.el" (18119 50971))
 ;;; Generated autoloads from muse-mode.el
 
-(autoload (quote muse-mode) "muse-mode" "\
+(autoload 'muse-mode "muse-mode" "\
 Muse is an Emacs mode for authoring and publishing documents.
 \\{muse-mode-map}
 
 \(fn)" t nil)
 
-(autoload (quote muse-mode-choose-mode) "muse-mode" "\
+(autoload 'muse-mode-choose-mode "muse-mode" "\
 Turn the proper Emacs Muse related mode on for this file.
 
 \(fn)" nil nil)
 
-(autoload (quote muse-insert-list-item) "muse-mode" "\
+(autoload 'muse-insert-list-item "muse-mode" "\
 Insert a list item at the current point, taking into account
 your current list type and indentation level.
 
 \(fn)" t nil)
 
-(autoload (quote muse-increase-list-item-indentation) "muse-mode" "\
+(autoload 'muse-increase-list-item-indentation "muse-mode" "\
 Increase the indentation of the current list item.
 
 \(fn)" t nil)
 
-(autoload (quote muse-decrease-list-item-indentation) "muse-mode" "\
+(autoload 'muse-decrease-list-item-indentation "muse-mode" "\
 Decrease the indentation of the current list item.
 
 \(fn)" t nil)
 
-(autoload (quote muse-insert-relative-link-to-file) "muse-mode" "\
+(autoload 'muse-insert-relative-link-to-file "muse-mode" "\
 Insert a relative link to a file, with optional description, at point.
 
 \(fn)" t nil)
 
-(autoload (quote muse-edit-link-at-point) "muse-mode" "\
+(autoload 'muse-edit-link-at-point "muse-mode" "\
 Edit the current link.
 Do not rename the page originally referred to.
 
 \(fn)" t nil)
 
-(autoload (quote muse-browse-result) "muse-mode" "\
+(autoload 'muse-browse-result "muse-mode" "\
 Visit the current page's published result.
 
 \(fn STYLE &optional OTHER-WINDOW)" t nil)
 
-(autoload (quote muse-follow-name-at-point) "muse-mode" "\
+(autoload 'muse-follow-name-at-point "muse-mode" "\
 Visit the link at point.
 
 \(fn &optional OTHER-WINDOW)" t nil)
 
-(autoload (quote muse-follow-name-at-point-other-window) "muse-mode" "\
+(autoload 'muse-follow-name-at-point-other-window "muse-mode" "\
 Visit the link at point in other window.
 
 \(fn)" t nil)
 
-(autoload (quote muse-next-reference) "muse-mode" "\
+(autoload 'muse-next-reference "muse-mode" "\
 Move forward to next Muse link or URL, cycling if necessary.
 
 \(fn)" t nil)
 
-(autoload (quote muse-previous-reference) "muse-mode" "\
+(autoload 'muse-previous-reference "muse-mode" "\
 Move backward to the next Muse link or URL, cycling if necessary.
 In case of Emacs x <= 21 and ignoring of intangible properties (see
 `muse-mode-intangible-links').
@@ -138,45 +138,70 @@ This function is not entirely accurate, but it's close enough.
 
 \(fn)" t nil)
 
-(autoload (quote muse-what-changed) "muse-mode" "\
+(autoload 'muse-what-changed "muse-mode" "\
 Show the unsaved changes that have been made to the current file.
 
 \(fn)" t nil)
 
-(autoload (quote muse-search-with-command) "muse-mode" "\
+(autoload 'muse-search-with-command "muse-mode" "\
 Search for the given TEXT string in the project directories
 using the specified command.
 
 \(fn TEXT)" t nil)
 
-(autoload (quote muse-search) "muse-mode" "\
+(autoload 'muse-search "muse-mode" "\
 Search for the given TEXT using the default grep command.
 
 \(fn)" t nil)
 
-(autoload (quote muse-find-backlinks) "muse-mode" "\
+(autoload 'muse-find-backlinks "muse-mode" "\
 Grep for the current pagename in all the project directories.
 
 \(fn)" t nil)
 
-(autoload (quote muse-index) "muse-mode" "\
+(autoload 'muse-index "muse-mode" "\
 Display an index of all known Muse pages.
 
 \(fn)" t nil)
 
-(autoload (quote muse-insert-tag) "muse-mode" "\
+(autoload 'muse-insert-tag "muse-mode" "\
 Insert a tag interactively with a blank line after it.
 
 \(fn TAG)" t nil)
 
+(autoload 'muse-list-edit-minor-mode "muse-mode" "\
+This is a global minor mode for editing files with lists.
+It is meant to be used with other major modes, and not with Muse mode.
+
+Interactively, with no prefix argument, toggle the mode.
+With universal prefix ARG turn mode on.
+With zero or negative ARG turn mode off.
+
+This minor mode provides the Muse keybindings for editing lists,
+and support for filling lists properly.
+
+It recognizes not only Muse-style lists, which use the \"-\"
+character or numbers, but also lists that use asterisks or plus
+signs.  This should make the minor mode generally useful.
+
+Definition lists and footnotes are also recognized.
+
+Note that list items may omit leading spaces, for compatibility
+with modes that set `left-margin', such as
+`debian-changelog-mode'.
+
+\\{muse-list-edit-minor-mode-map}
+
+\(fn &optional ARG)" t nil)
+
 ;;;***
 
 ;;;### (autoloads (muse-project-publish muse-project-publish-this-file
 ;;;;;;  muse-project-find-file) "muse-project" "muse-project.el"
-;;;;;;  (18037 27554))
+;;;;;;  (18119 50971))
 ;;; Generated autoloads from muse-project.el
 
-(autoload (quote muse-project-find-file) "muse-project" "\
+(autoload 'muse-project-find-file "muse-project" "\
 Open the Muse page given by NAME in PROJECT.
 If COMMAND is non-nil, it is the function used to visit the file.
 If DIRECTORY is non-nil, it is the directory in which the page
@@ -185,7 +210,7 @@ first directory within the project's fileset is used.
 
 \(fn NAME PROJECT &optional COMMAND DIRECTORY)" t nil)
 
-(autoload (quote muse-project-publish-this-file) "muse-project" "\
+(autoload 'muse-project-publish-this-file "muse-project" "\
 Publish the currently-visited file according to `muse-project-alist',
 prompting if more than one style applies.
 
@@ -193,7 +218,7 @@ If FORCE is given, publish the file even if it is up-to-date.
 
 \(fn &optional FORCE)" t nil)
 
-(autoload (quote muse-project-publish) "muse-project" "\
+(autoload 'muse-project-publish "muse-project" "\
 Publish the pages of PROJECT that need publishing.
 
 \(fn PROJECT &optional FORCE)" t nil)
@@ -201,10 +226,10 @@ Publish the pages of PROJECT that need publishing.
 ;;;***
 
 ;;;### (autoloads (muse-browse-url) "muse-protocols" "muse-protocols.el"
-;;;;;;  (18032 42403))
+;;;;;;  (18119 51965))
 ;;; Generated autoloads from muse-protocols.el
 
-(autoload (quote muse-browse-url) "muse-protocols" "\
+(autoload 'muse-browse-url "muse-protocols" "\
 Handle URL with the function specified in `muse-url-protocols'.
 If OTHER-WINDOW is non-nil, open in a different window.
 
@@ -213,16 +238,16 @@ If OTHER-WINDOW is non-nil, open in a different window.
 ;;;***
 
 ;;;### (autoloads (muse-publish-this-file muse-publish-file muse-publish-region)
-;;;;;;  "muse-publish" "muse-publish.el" (18037 26981))
+;;;;;;  "muse-publish" "muse-publish.el" (18126 12390))
 ;;; Generated autoloads from muse-publish.el
 
-(autoload (quote muse-publish-region) "muse-publish" "\
+(autoload 'muse-publish-region "muse-publish" "\
 Apply the given STYLE's markup rules to the given region.
 The result is placed in a new buffer that includes TITLE in its name.
 
 \(fn BEG END &optional TITLE STYLE)" t nil)
 
-(autoload (quote muse-publish-file) "muse-publish" "\
+(autoload 'muse-publish-file "muse-publish" "\
 Publish the given FILE in a particular STYLE to OUTPUT-DIR.
 If the argument FORCE is nil, each file is only published if it is
 newer than the published version.  If the argument FORCE is non-nil,
@@ -230,7 +255,7 @@ the file is published no matter what.
 
 \(fn FILE STYLE &optional OUTPUT-DIR FORCE)" t nil)
 
-(autoload (quote muse-publish-this-file) "muse-publish" "\
+(autoload 'muse-publish-this-file "muse-publish" "\
 Publish the currently-visited file.
 Prompt for both the STYLE and OUTPUT-DIR if they are not
 supplied.
@@ -242,19 +267,19 @@ supplied.
 ;;;### (autoloads nil nil ("../contrib/cgi.el" "../contrib/httpd.el"
 ;;;;;;  "../experimental/muse-cite.el" "../experimental/muse-mathml.el"
 ;;;;;;  "../experimental/muse-protocol-iw.el" "../experimental/muse-split.el"
-;;;;;;  "muse-backlink.el" "muse-book.el" "muse-docbook.el" "muse-groff.el"
-;;;;;;  "muse-html.el" "muse-http.el" "muse-import-xml.el" "muse-journal.el"
-;;;;;;  "muse-latex.el" "muse-latex2png.el" "muse-poem.el" "muse-regexps.el"
-;;;;;;  "muse-texinfo.el" "muse-wiki.el" "muse-xml-common.el" "muse-xml.el")
-;;;;;;  (18037 27643 480221))
+;;;;;;  "muse-backlink.el" "muse-book.el" "muse-context.el" "muse-docbook.el"
+;;;;;;  "muse-groff.el" "muse-html.el" "muse-http.el" "muse-import-xml.el"
+;;;;;;  "muse-journal.el" "muse-latex.el" "muse-latex2png.el" "muse-poem.el"
+;;;;;;  "muse-regexps.el" "muse-texinfo.el" "muse-wiki.el" "muse-xml-common.el"
+;;;;;;  "muse-xml.el") (18127 40985 729091))
 
 ;;;***
 
 ;;;### (autoloads (muse-blosxom-new-entry) "muse-blosxom" "muse-blosxom.el"
-;;;;;;  (18037 26515))
+;;;;;;  (18127 36528))
 ;;; Generated autoloads from muse-blosxom.el
 
-(autoload (quote muse-blosxom-new-entry) "muse-blosxom" "\
+(autoload 'muse-blosxom-new-entry "muse-blosxom" "\
 Start a new blog entry with given CATEGORY.
 The filename of the blog entry is derived from TITLE.
 The page will be initialized with the current date and TITLE.
