@@ -1,12 +1,12 @@
 ;;; muse-html.el --- publish to HTML and XHTML
 
-;; Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; This file is part of Emacs Muse.  It is not part of GNU Emacs.
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -28,6 +28,15 @@
 ;; sample publishing header so that when editing the resulting XHTML
 ;; file, Emacs would use the proper encoding.
 
+;; Sun Jiyang (sunyijiang AT gmail DOT com) came up with the idea for
+;; the <src> tag and provided an implementation for emacs-wiki.
+
+;; Charles Wang (wcy123 AT gmail DOT com) provided an initial
+;; implementation of the <src> tag for Muse.
+
+;; Clinton Ebadi (clinton AT unknownlamer DOT org) provided further
+;; ideas for the implementation of the <src> tag.
+
 ;;; Code:
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -38,6 +47,7 @@
 
 (require 'muse-publish)
 (require 'muse-regexps)
+(require 'muse-xml-common)
 
 (defgroup muse-html nil
   "Options controlling the behavior of Muse HTML publishing."
@@ -127,8 +137,9 @@ An example of using <link> is as follows.
       (let ((maintainer (muse-style-element :maintainer)))
         (when maintainer
           (concat \"<link rev=\\\"made\\\" href=\\\"\" maintainer \"\\\">\")))
+    </lisp><lisp>
+      (muse-style-element :style-sheet muse-publishing-current-style)
     </lisp>
-    <lisp>muse-html-style-sheet</lisp>
   </head>
   <body>
     <h1><lisp>
@@ -168,8 +179,9 @@ An example of using <link> is as follows.
       (let ((maintainer (muse-style-element :maintainer)))
         (when maintainer
           (concat \"<link rev=\\\"made\\\" href=\\\"\" maintainer \"\\\" />\")))
+    </lisp><lisp>
+      (muse-style-element :style-sheet muse-publishing-current-style)
     </lisp>
-    <lisp>muse-xhtml-style-sheet</lisp>
   </head>
   <body>
     <h1><lisp>
@@ -199,50 +211,22 @@ header style is different from your link style."
   :group 'muse-html)
 
 (defcustom muse-html-table-attributes
-  "class=\"muse-table\" border=\"2\" cellpadding=\"5\""
+  " class=\"muse-table\" border=\"2\" cellpadding=\"5\""
   "The attribute to be used with HTML <table> tags.
-Note that since Muse supports direct insertion of HTML tags, you
-can easily create any kind of table you want, as long as each
-line begins at column 0 (to prevent it from being blockquoted).
-To make such a table, use this idiom:
-
-  <verbatim>
-  <table>
-    [... contents of my table, in raw HTML ...]
-  </verbatim></table>
-
-It may look strange to have the tags out of sequence, but this is
-because the Muse verbatim tag is handled during a different pass
-than the HTML table tag."
+Note that Muse supports insertion of raw HTML tags, as long
+as you wrap the region in <literal></literal>."
   :type 'string
   :group 'muse-html)
 
 (defcustom muse-html-markup-regexps
-  `(;; Join together the parts of a table
-    (10000 ,(concat "  </t\\(body\\|head\\|foot\\)>\\s-*</table>"
-                    "\\([" muse-regexp-blank "]*\n\\)\\{0,2\\}"
-                    "[" muse-regexp-blank "]*"
-                    "<table[^>]*>\\s-*<t\\1>\n") 0 "")
-    (10100 ,(concat "</table>"
-                    "\\([" muse-regexp-blank "]*\n\\)\\{0,2\\}"
-                    "[" muse-regexp-blank "]*"
-                    "<table[^>]*>\n")
-           0 "")
-
-    ;; Join together the parts of a list
-    (10200 ,(concat "</\\([oud]l\\)>"
-                    "\\([" muse-regexp-blank "]*\n\\)\\{0,2\\}"
-                    "[" muse-regexp-blank "]*"
-                    "<\\1>\\s-*")
-           0 "")
-
-    ;; Beginning of doc, end of doc, or plain paragraph separator
-    (10300 ,(concat "\\(\n</\\(blockquote\\|center\\)>\\)?"
-                    "\\(\\(\n\\(["
-                    muse-regexp-blank
-                    "]*\n\\)+\\)\\|\\`\\s-*\\|\\s-*\\'\\)"
-                    "\\(<\\(blockquote\\|center\\)>\n\\)?")
-           0 muse-html-markup-paragraph))
+  `(;; Beginning of doc, end of doc, or plain paragraph separator
+    (10000 ,(concat "\\(\\(\n\\(?:[" muse-regexp-blank "]*\n\\)*"
+                    "\\([" muse-regexp-blank "]*\n\\)\\)"
+                    "\\|\\`\\s-*\\|\\s-*\\'\\)")
+           ;; this is somewhat repetitive because we only require the
+           ;; line just before the paragraph beginning to be not
+           ;; read-only
+           3 muse-html-markup-paragraph))
   "List of markup rules for publishing a Muse page to HTML.
 For more on the structure of this list, see `muse-publish-markup-regexps'."
   :type '(repeat (choice
@@ -265,13 +249,20 @@ For more on the structure of this list, see
   :group 'muse-html)
 
 (defcustom muse-html-markup-strings
-  '((image-with-desc . "<img src=\"%s\" alt=\"%s\">")
-    (image-link      . "<img src=\"%s\" alt=\"\">")
-    (url-with-image  . "<a class=\"image-link\" href=\"%s\"><img src=\"%s\"></a>")
-    (url-link        . "<a href=\"%s\">%s</a>")
-    (internal-link   . "<a href=\"#%s\">%s</a>")
+  '((image-with-desc . "<table class=\"image\" width=\"100%%\">
+  <tr><td align=\"center\"><img src=\"%1%.%2%\" alt=\"%3%\"></td></tr>
+  <tr><td align=\"center\" class=\"image-caption\">%3%</td></tr>
+</table>")
+    (image           . "<img src=\"%s.%s\" alt=\"\">")
+    (image-link      . "<a class=\"image-link\" href=\"%s\">
+<img src=\"%s.%s\"></a>")
+    (anchor-ref      . "<a href=\"#%s\">%s</a>")
+    (url             . "<a href=\"%s\">%s</a>")
+    (link            . "<a href=\"%s\">%s</a>")
+    (link-and-anchor . "<a href=\"%s#%s\">%s</a>")
     (email-addr      . "<a href=\"mailto:%s\">%s</a>")
-    (emdash          . " &mdash; ")
+    (anchor          . "<a name=\"%1%\" id=\"%1%\">")
+    (emdash          . "%s&mdash;%s")
     (comment-begin   . "<!-- ")
     (comment-end     . " -->")
     (rule            . "<hr>")
@@ -291,6 +282,10 @@ For more on the structure of this list, see
     (end-underline   . "</u>")
     (begin-literal   . "<code>")
     (end-literal     . "</code>")
+    (begin-cite      . "<span class=\"citation\">")
+    (begin-cite-author . "<span class=\"citation-author\">")
+    (begin-cite-year . "<span class=\"citation-year\">")
+    (end-cite        . "</span>")
     (begin-emph      . "<em>")
     (end-emph        . "</em>")
     (begin-more-emph . "<strong>")
@@ -305,17 +300,32 @@ For more on the structure of this list, see
     (end-verse       . "</p>")
     (begin-example   . "<pre class=\"example\">")
     (end-example     . "</pre>")
-    (begin-center    . "<center>\n")
-    (end-center      . "\n</center>")
+    (begin-center    . "<center>\n<p>")
+    (end-center      . "</p>\n</center>")
     (begin-quote     . "<blockquote>\n")
     (end-quote       . "\n</blockquote>")
-    (begin-uli       . "<ul>\n<li>")
-    (end-uli         . "</li>\n</ul>")
-    (begin-oli       . "<ol>\n<li>")
-    (end-oli         . "</li>\n</ol>")
-    (begin-ddt       . "<dl>\n<dt><strong>")
-    (start-dde       . "</strong></dt>\n<dd>")
-    (end-ddt         . "</dd>\n</dl>"))
+    (begin-quote-item . "<p class=\"quoted\">")
+    (end-quote-item  . "</p>")
+    (begin-uli       . "<ul>\n")
+    (end-uli         . "\n</ul>")
+    (begin-uli-item  . "<li>")
+    (end-uli-item    . "</li>")
+    (begin-oli       . "<ol>\n")
+    (end-oli         . "\n</ol>")
+    (begin-oli-item  . "<li>")
+    (end-oli-item    . "</li>")
+    (begin-dl        . "<dl>\n")
+    (end-dl          . "\n</dl>")
+    (begin-ddt       . "<dt><strong>")
+    (end-ddt         . "</strong></dt>")
+    (begin-dde       . "<dd>")
+    (end-dde         . "</dd>")
+    (begin-table     . "<table%s>\n")
+    (end-table       . "</table>")
+    (begin-table-row . "    <tr>\n")
+    (end-table-row   . "    </tr>\n")
+    (begin-table-entry . "      <%s>")
+    (end-table-entry . "</%s>\n"))
   "Strings used for marking up text as HTML.
 These cover the most basic kinds of markup, the handling of which
 differs little between the various styles."
@@ -323,9 +333,13 @@ differs little between the various styles."
   :group 'muse-html)
 
 (defcustom muse-xhtml-markup-strings
-  '((image-with-desc . "<img src=\"%s\" alt=\"%s\" />")
-    (image-link      . "<img src=\"%s\" alt=\"\" />")
-    (url-with-image  . "<a class=\"image-link\" href=\"%s\"><img src=\"%s\" alt=\"\" /></a>")
+  '((image-with-desc . "<table class=\"image\" width=\"100%%\">
+  <tr><td align=\"center\"><img src=\"%1%.%2%\" alt=\"%3%\" /></td></tr>
+  <tr><td align=\"center\" class=\"image-caption\">%3%</td></tr>
+</table>")
+    (image           . "<img src=\"%s.%s\" alt=\"\" />")
+    (image-link      . "<a class=\"image-link\" href=\"%s\">
+<img src=\"%s.%s\" alt=\"\" /></a>")
     (rule            . "<hr />")
     (fn-sep          . "<hr />\n")
     (begin-underline . "<span style=\"text-decoration: underline;\">")
@@ -344,24 +358,28 @@ searched."
   :type '(alist :key-type symbol :value-type string)
   :group 'muse-html)
 
+(defcustom muse-xhtml1.1-markup-strings
+  '((anchor          . "<a id=\"%s\">"))
+  "Strings used for marking up text as XHTML 1.1.
+These cover the most basic kinds of markup, the handling of which
+differs little between the various styles.
+
+If a markup rule is not found here, `muse-xhtml-markup-strings'
+and `muse-html-markup-strings' are searched."
+  :type '(alist :key-type symbol :value-type string)
+  :group 'muse-html)
+
 (defcustom muse-html-markup-tags
-  '(("class" t t muse-html-class-tag))
-  "A list of tag specifications, for specially marking up HTML."
+  '(("class" t t   t muse-html-class-tag)
+    ("src"   t t nil muse-html-src-tag))
+ "A list of tag specifications, for specially marking up HTML."
   :type '(repeat (list (string :tag "Markup tag")
                        (boolean :tag "Expect closing tag" :value t)
                        (boolean :tag "Parse attributes" :value nil)
+                       (boolean :tag "Nestable" :value nil)
                        function))
   :group 'muse-html)
 
-(defcustom muse-html-markup-specials
-  '((?\" . "&quot;")
-    (?\< . "&lt;")
-    (?\> . "&gt;")
-    (?\& . "&amp;"))
-  "A table of characters which must be represented specially."
-  :type '(alist :key-type character :value-type string)
-  :group 'muse-html)
-
 (defcustom muse-html-meta-http-equiv "Content-Type"
   "The http-equiv attribute used for the HTML <meta> tag."
   :type 'string
@@ -384,66 +402,41 @@ string, this string will be used to force a particular charset"
   :type '(choice string symbol)
   :group 'muse-html)
 
-(defcustom muse-html-charset-default "iso-8859-1"
-  "The default HTML meta charset to use if no translation is found in
-`muse-html-encoding-map'."
-  :type 'string
-  :group 'muse-html)
-
 (defcustom muse-html-encoding-default 'iso-8859-1
   "The default Emacs buffer encoding to use in published files.
 This will be used if no special characters are found."
   :type 'symbol
   :group 'muse-html)
 
-(defcustom muse-html-encoding-map
-  '((iso-8859-1         . "iso-8859-1")
-    (iso-2022-jp        . "iso-2022-jp")
-    (utf-8              . "utf-8")
-    (japanese-iso-8bit  . "euc-jp")
-    (chinese-big5       . "big5")
-    (mule-utf-8         . "utf-8")
-    (chinese-iso-8bit   . "gb2312")
-    (chinese-gbk        . "gbk"))
-  "An alist mapping emacs coding systems to appropriate HTML charsets.
-Use the base name of the coding system (i.e. without the -unix)."
-  :type '(alist :key-type coding-system :value-type string)
+(defcustom muse-html-charset-default "iso-8859-1"
+  "The default HTML meta charset to use if no translation is found in
+`muse-html-encoding-map'."
+  :type 'string
   :group 'muse-html)
 
-(defun muse-html-transform-content-type (content-type)
-  "Using `muse-html-encoding-map', try and resolve an emacs coding
-system to an associated HTML coding system. If no match is found,
-`muse-html-charset-default' is used instead."
-  (let ((match (and (fboundp 'coding-system-base)
-                    (assoc (coding-system-base content-type)
-                           muse-html-encoding-map))))
-    (if match
-        (cdr match)
-      muse-html-charset-default)))
-
 (defun muse-html-insert-anchor (anchor)
   "Insert an anchor, either around the word at point, or within a tag."
-  (unless (get-text-property (match-end 1) 'noemphasis)
-    (skip-chars-forward (concat muse-regexp-blank "\n"))
-    (if (looking-at "<\\([^ />]+\\)>")
-        (let ((tag (match-string 1)))
-          (goto-char (match-end 0))
-          (insert "<a name=\"" anchor "\" id=\"" anchor "\">")
-          (when muse-html-anchor-on-word
-            (or (and (search-forward (format "</%s>" tag)
-                                     (muse-line-end-position) t)
-                     (goto-char (match-beginning 0)))
-                (forward-word 1)))
-          (insert "</a>"))
-      (insert "<a name=\"" anchor "\" id=\"" anchor "\">")
-      (when muse-html-anchor-on-word
-        (forward-word 1))
-      (insert "</a>\n"))))
+  (skip-chars-forward (concat muse-regexp-blank "\n"))
+  (if (looking-at (concat "<\\([^" muse-regexp-blank "/>\n]+\\)>"))
+      (let ((tag (match-string 1)))
+        (goto-char (match-end 0))
+        (muse-insert-markup (muse-markup-text 'anchor anchor))
+        (when muse-html-anchor-on-word
+          (or (and (search-forward (format "</%s>" tag)
+                                   (muse-line-end-position) t)
+                   (goto-char (match-beginning 0)))
+              (forward-word 1)))
+        (muse-insert-markup "</a>"))
+    (muse-insert-markup (muse-markup-text 'anchor anchor))
+    (when muse-html-anchor-on-word
+      (forward-word 1))
+    (muse-insert-markup "</a>\n")))
 
 (defun muse-html-markup-anchor ()
-  (save-match-data
-    (muse-html-insert-anchor (match-string 2)))
-  (match-string 1))
+  (unless (get-text-property (match-end 1) 'muse-link)
+    (save-match-data
+      (muse-html-insert-anchor (match-string 2)))
+    (match-string 1)))
 
 (defun muse-html-markup-paragraph ()
   (let ((end (copy-marker (match-end 0) t)))
@@ -452,7 +445,9 @@ system to an associated HTML coding system. If no match is found,
             (save-match-data
               (and (re-search-backward "<\\(/?\\)p[ >]" nil t)
                    (not (string-equal (match-string 1) "/")))))
-      (insert "</p>"))
+      (when (get-text-property (1- (point)) 'end-list)
+        (goto-char (previous-single-property-change (1- (point)) 'end-list)))
+      (muse-insert-markup "</p>"))
     (goto-char end))
   (cond
    ((eobp)
@@ -461,53 +456,33 @@ system to an associated HTML coding system. If no match is found,
    ((eq (char-after) ?\<)
     (cond
      ((looking-at "<\\(em\\|strong\\|code\\|span\\)[ >]")
-      (insert "<p>"))
+      (muse-insert-markup "<p>"))
      ((looking-at "<a ")
-      (if (looking-at "<a[^>]+><img")
-          (insert "<p class=\"image-link\">")
-        (insert "<p>")))
+      (if (looking-at "<a[^>\n]+><img")
+          (muse-insert-markup "<p class=\"image-link\">")
+        (muse-insert-markup "<p>")))
      ((looking-at "<img[ >]")
-      (insert "<p class=\"image-link\">"))))
+      (muse-insert-markup "<p class=\"image\">"))
+     (t
+      (forward-char 1)
+      nil)))
    ((muse-looking-back "\\(</h[1-4]>\\|<hr>\\)\n\n")
-    (insert "<p class=\"first\">"))
-   ((muse-looking-back "<\\(blockquote\\|center\\)>\n")
-    (insert "<p class=\"quoted\">"))
+    (muse-insert-markup "<p class=\"first\">"))
    (t
-    (insert "<p>"))))
-
-(defun muse-html-escape-string (str &rest ignored)
-  "Convert to character entities any non-alphanumeric characters
-outside a few punctuation symbols, that risk being misinterpreted
-if not escaped."
-  (when str
-    (let (pos code len ch)
-      (save-match-data
-        (while (setq pos (string-match (concat "[^-"
-                                               muse-regexp-alnum
-                                               "/:._=@\\?~#%\"\\+<>&;]")
-                                       str pos))
-          (setq ch (aref str pos)
-                code (concat "&#"
-                                 (int-to-string
-                                  (cond ((fboundp 'char-to-ucs)
-                                         (char-to-ucs ch))
-                                        ((fboundp 'char-to-int)
-                                         (char-to-int ch))
-                                        (t ch)))
-                                 ";")
-                len (length code)
-                str (concat (substring str 0 pos)
-                            code
-                            (when (< pos (length str))
-                              (substring str (1+ pos) nil)))
-                pos (+ len pos)))
-        str))))
+    (muse-insert-markup "<p>"))))
 
 (defun muse-html-markup-footnote ()
-  (if (/= (muse-line-beginning-position) (match-beginning 0))
-      "<sup><a name=\"fnr.\\1\" href=\"#fn.\\1\">\\1</a></sup>"
+  (cond
+   ((get-text-property (match-beginning 0) 'muse-link)
+    nil)
+   ((= (muse-line-beginning-position) (match-beginning 0))
     (prog1
-        "<p class=\"footnote\"><a name=\"fn.\\1\" href=\"#fnr.\\1\">\\1.</a>"
+        (let ((text (match-string 1)))
+          (muse-insert-markup
+           (concat "<p class=\"footnote\">"
+                   "<a class=\"footnum\" name=\"fn." text
+                   "\" href=\"#fnr." text "\">"
+                   text ".</a>")))
       (save-excursion
         (save-match-data
           (let* ((beg (goto-char (match-end 0)))
@@ -519,87 +494,153 @@ if not escaped."
                                               muse-regexp-blank
                                               "]+\\([^\n]\\)")
                                       end t)
-              (replace-match "\\1" t))))))))
+              (replace-match "\\1" t)))))
+      (replace-match "")))
+   (t (let ((text (match-string 1)))
+        (muse-insert-markup
+         (concat "<sup><a class=\"footref\" name=\"fnr." text
+                 "\" href=\"#fn." text "\">"
+                 text "</a></sup>")))
+      (replace-match ""))))
 
 (defun muse-html-markup-table ()
-  (let* ((str (prog1
-                  (match-string 1)
-                (delete-region (match-beginning 0) (match-end 0))))
-         (fields (split-string str "\\s-*|+\\s-*"))
-         (type (and (string-match "\\s-*\\(|+\\)\\s-*" str)
-                    (length (match-string 1 str))))
-         (part (cond ((= type 1) "tbody")
-                     ((= type 2) "thead")
-                     ((= type 3) "tfoot")))
-         (col (cond ((= type 1) "td")
-                    ((= type 2) "th")
-                    ((= type 3) "td"))))
-    (insert "<table " muse-html-table-attributes ">\n"
-            "  <" part ">\n"
-            "    <tr>\n")
-    (dolist (field fields)
-      (insert "      <" col ">" field "</" col ">\n"))
-    (insert "    </tr>\n"
-            "  </" part ">\n"
-            "</table>\n")))
+  (muse-xml-markup-table muse-html-table-attributes))
 
 ;; Handling of tags for HTML
 
+(defun muse-html-strip-links (string)
+  "Remove all HTML links from STRING."
+  (muse-replace-regexp-in-string "\\(<a .*?>\\|</a>\\)" "" string nil t))
+
 (defun muse-html-insert-contents (depth)
+  "Scan the current document and generate a table of contents at point.
+DEPTH indicates how many levels of headings to include.  The default is 2."
   (let ((max-depth (or depth 2))
         (index 1)
-        base contents l)
+        base contents l end)
     (save-excursion
       (goto-char (point-min))
       (search-forward "Page published by Emacs Muse begins here" nil t)
       (catch 'done
-        (while (re-search-forward "^<h\\([0-9]+\\)>\\(.+?\\)</h\\1>" nil t)
-          (unless (get-text-property (point) 'read-only)
+        (while (re-search-forward "<h\\([0-9]+\\)>\\(.+?\\)</h\\1>$" nil t)
+          (unless (and (get-text-property (point) 'read-only)
+                       (not (get-text-property (match-beginning 0)
+                                               'muse-contents)))
+            (remove-text-properties (match-beginning 0) (match-end 0)
+                                    '(muse-contents nil))
             (setq l (1- (string-to-number (match-string 1))))
             (if (null base)
                 (setq base l)
               (if (< l base)
                   (throw 'done t)))
             (when (<= l max-depth)
-              (setq contents (cons (cons l (muse-match-string-no-properties 2))
+              ;; escape specials now before copying the text, so that we
+              ;; can deal sanely with both emphasis in titles and
+              ;; special characters
+              (goto-char (match-end 2))
+              (setq end (point-marker))
+              (muse-publish-escape-specials (match-beginning 2) end
+                                            nil 'document)
+              (muse-publish-mark-read-only (match-beginning 2) end)
+              (setq contents (cons (cons l (buffer-substring-no-properties
+                                            (match-beginning 2) end))
                                    contents))
+              (set-marker end nil)
               (goto-char (match-beginning 2))
               (muse-html-insert-anchor (concat "sec" (int-to-string index)))
               (setq index (1+ index)))))))
-    (setq index 1 contents (reverse contents))
+    (setq index 1 contents (nreverse contents))
     (let ((depth 1) (sub-open 0) (p (point)))
-      (insert "<dl class=\"contents\">\n")
+      (muse-insert-markup "<div class=\"contents\">\n<dl>\n")
       (while contents
-        (insert "<dt class=\"contents\">\n")
-        (insert "<a href=\"#sec" (int-to-string index) "\">"
-                (muse-publish-strip-tags (cdar contents))
-                "</a>\n")
-        (setq index (1+ index))
-        (insert "</dt>\n")
-        (setq depth (caar contents)
+        (muse-insert-markup "<dt>\n"
+                            "<a href=\"#sec" (int-to-string index) "\">"
+                            (muse-html-strip-links (cdar contents))
+                            "</a>\n"
+                            "</dt>\n")
+        (setq index (1+ index)
+              depth (caar contents)
               contents (cdr contents))
-        (if contents
-            (cond
-             ((< (caar contents) depth)
-              (let ((idx (caar contents)))
-                (while (< idx depth)
-                  (insert "</dl>\n</dd>\n")
-                  (setq sub-open (1- sub-open)
-                        idx (1+ idx)))))
-             ((> (caar contents) depth) ; can't jump more than one ahead
-              (insert "<dd>\n<dl class=\"contents\">\n")
-              (setq sub-open (1+ sub-open))))))
+        (when contents
+          (cond
+           ((< (caar contents) depth)
+            (let ((idx (caar contents)))
+              (while (< idx depth)
+                (muse-insert-markup "</dl>\n</dd>\n")
+                (setq sub-open (1- sub-open)
+                      idx (1+ idx)))))
+           ((> (caar contents) depth) ; can't jump more than one ahead
+            (muse-insert-markup "<dd>\n<dl>\n")
+            (setq sub-open (1+ sub-open))))))
       (while (> sub-open 0)
-        (insert "</dl>\n</dd>\n")
+        (muse-insert-markup "</dl>\n</dd>\n")
         (setq sub-open (1- sub-open)))
-      (insert "</dl>\n")
+      (muse-insert-markup "</dl>\n</div>\n")
       (muse-publish-mark-read-only p (point)))))
 
+(defun muse-html-denote-headings ()
+  "Place a text property on any headings in the current buffer.
+This allows the headings to be picked up later on if publishing a
+table of contents."
+  (save-excursion
+    (goto-char (point-min))
+    (search-forward "Page published by Emacs Muse begins here" nil t)
+    (while (re-search-forward "<h\\([0-9]+\\)>\\(.+?\\)</h\\1>$" nil t)
+      (unless (get-text-property (point) 'read-only)
+        (add-text-properties (match-beginning 0) (match-end 0)
+                             '(muse-contents t))))))
+
 (defun muse-html-class-tag (beg end attrs)
   (goto-char beg)
-  (insert "<span class=\"" (cdr (assoc "name" attrs)) "\">")
+  (muse-insert-markup "<span class=\"" (cdr (assoc "name" attrs)) "\">")
   (goto-char end)
-  (insert "</span>"))
+  (muse-insert-markup "</span>"))
+
+(defun muse-html-src-tag (beg end attrs)
+  "Publish the region using htmlize.
+The language to use may be specified by the \"lang\" attribute.
+
+Muse will look for a function named LANG-mode, where LANG is the
+value of the \"lang\" attribute.
+
+This tag requires htmlize 1.34 or later in order to work."
+  (if (condition-case nil
+          (progn
+            (require 'htmlize)
+            (if (fboundp 'htmlize-region-for-paste)
+                nil
+              (muse-display-warning
+               (concat "The `htmlize-region-for-paste' function was not"
+                       " found.\nThis is available in htmlize.el 1.34"
+                       " or later."))
+              t))
+        (error nil t))
+      ;; if htmlize.el was not found, treat this like an example tag
+      (muse-publish-example-tag beg end)
+    (muse-publish-ensure-block beg end)
+    (let* ((mode (and (assoc "lang" attrs)
+                      (intern (concat (cdr (assoc "lang" attrs))
+                                      "-mode"))))
+           (text (muse-delete-and-extract-region beg end))
+           (htmltext
+            (with-temp-buffer
+              (insert text)
+              (if (functionp mode)
+                  (funcall mode)
+                (fundamental-mode))
+              (font-lock-fontify-buffer)
+              ;; silence the byte-compiler
+              (when (fboundp 'htmlize-region-for-paste)
+                ;; transform the region to HTML
+                (htmlize-region-for-paste (point-min) (point-max))))))
+      (save-restriction
+        (narrow-to-region (point) (point))
+        (insert htmltext)
+        (goto-char (point-min))
+        (re-search-forward "<pre\\([^>]*\\)>\n?" nil t)
+        (replace-match "<pre class=\"src\">")
+        (goto-char (point-max))
+        (muse-publish-mark-read-only (point-min) (point-max))))))
 
 ;; Register the Muse HTML Publisher
 
@@ -609,14 +650,13 @@ if not escaped."
 (defun muse-html-encoding ()
   (if (stringp muse-html-meta-content-encoding)
       muse-html-meta-content-encoding
-    (muse-html-transform-content-type
+    (muse-xml-transform-content-type
      (or (and (boundp 'buffer-file-coding-system)
               buffer-file-coding-system)
-         muse-html-encoding-default))))
+         muse-html-encoding-default)
+     muse-html-charset-default)))
 
 (defun muse-html-prepare-buffer ()
-  (set (make-local-variable 'muse-publish-url-transforms)
-       (cons 'muse-html-escape-string muse-publish-url-transforms))
   (make-local-variable 'muse-html-meta-http-equiv)
   (set (make-local-variable 'muse-html-meta-content-type)
        (if (save-match-data
@@ -625,69 +665,50 @@ if not escaped."
          (concat muse-html-meta-content-type "; charset="
                  (muse-html-encoding)))))
 
-(defun muse-html-fixup-tables ()
-  "Sort table parts."
-  (goto-char (point-min))
-  (let (last)
-    (while (re-search-forward "^<table[^>]*>$" nil t)
-      (unless (get-text-property (point) 'read-only)
-        (forward-line 1)
-        (save-restriction
-          (let ((beg (point)))
-            (narrow-to-region beg (and (re-search-forward "^</table>"
-                                                          nil t)
-                                       (match-beginning 0))))
-          (goto-char (point-min))
-          (let ((inhibit-read-only t))
-            (sort-subr nil
-                       (function
-                        (lambda ()
-                          (if (re-search-forward
-                               "^\\s-*<t\\(head\\|body\\|foot\\)>$" nil t)
-                              (goto-char (match-beginning 0))
-                            (goto-char (point-max)))))
-                       (function
-                        (lambda ()
-                          (if (re-search-forward
-                               "^\\s-*</t\\(head\\|body\\|foot\\)>$" nil t)
-                              (goto-char (match-end 0))
-                            (goto-char (point-max)))))
-                       (function
-                        (lambda ()
-                          (looking-at "\\s-*<t\\(head\\|body\\|foot\\)>")
-                          (cond ((string= (match-string 1) "head") 1)
-                                ((string= (match-string 1) "foot") 2)
-                                (t 3)))))))))))
+(defun muse-html-munge-buffer ()
+  (if muse-publish-generate-contents
+      (progn
+        (goto-char (car muse-publish-generate-contents))
+        (muse-html-insert-contents (cdr muse-publish-generate-contents))
+        (setq muse-publish-generate-contents nil))
+    (muse-html-denote-headings)))
 
 (defun muse-html-finalize-buffer ()
-  (when muse-publish-generate-contents
-    (goto-char (car muse-publish-generate-contents))
-    (muse-html-insert-contents (cdr muse-publish-generate-contents)))
   (when (and (boundp 'buffer-file-coding-system)
              (memq buffer-file-coding-system '(no-conversion undecided-unix)))
     ;; make it agree with the default charset
     (setq buffer-file-coding-system muse-html-encoding-default)))
 
-(unless (assoc "html" muse-publishing-styles)
-  (muse-define-style "html"
-                     :suffix    'muse-html-extension
-                     :regexps   'muse-html-markup-regexps
-                     :functions 'muse-html-markup-functions
-                     :strings   'muse-html-markup-strings
-                     :tags      'muse-html-markup-tags
-                     :specials  'muse-html-markup-specials
-                     :before    'muse-html-prepare-buffer
-                     :before-end 'muse-html-fixup-tables
-                     :after     'muse-html-finalize-buffer
-                     :header    'muse-html-header
-                     :footer    'muse-html-footer
-                     :browser   'muse-html-browse-file)
+;;; Register the Muse HTML and XHTML Publishers
 
-  (muse-derive-style "xhtml" "html"
-                     :suffix    'muse-xhtml-extension
-                     :strings   'muse-xhtml-markup-strings
-                     :header    'muse-xhtml-header
-                     :footer    'muse-xhtml-footer))
+(muse-define-style "html"
+                   :suffix    'muse-html-extension
+                   :regexps   'muse-html-markup-regexps
+                   :functions 'muse-html-markup-functions
+                   :strings   'muse-html-markup-strings
+                   :tags      'muse-html-markup-tags
+                   :specials  'muse-xml-decide-specials
+                   :before    'muse-html-prepare-buffer
+                   :before-end 'muse-html-munge-buffer
+                   :after     'muse-html-finalize-buffer
+                   :header    'muse-html-header
+                   :footer    'muse-html-footer
+                   :style-sheet 'muse-html-style-sheet
+                   :browser   'muse-html-browse-file)
+
+(muse-derive-style "xhtml" "html"
+                   :suffix    'muse-xhtml-extension
+                   :strings   'muse-xhtml-markup-strings
+                   :header    'muse-xhtml-header
+                   :footer    'muse-xhtml-footer
+                   :style-sheet 'muse-xhtml-style-sheet)
+
+;; xhtml1.0 is an alias for xhtml
+(muse-derive-style "xhtml1.0" "xhtml")
+
+;; xhtml1.1 has some quirks that need attention from us
+(muse-derive-style "xhtml1.1" "xhtml"
+                   :strings   'muse-xhtml1.1-markup-strings)
 
 (provide 'muse-html)
 
