@@ -1,12 +1,12 @@
 ;;; muse-latex.el --- publish entries in LaTex or PDF format
 
-;; Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; This file is part of Emacs Muse.  It is not part of GNU Emacs.
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -28,6 +28,15 @@
 ;; Trent Buck (trentbuck AT gmail DOT com) gave valuable advice for
 ;; how to treat LaTeX specials and the like.
 
+;; Matthias Kegelmann (mathias DOT kegelmann AT sdm DOT de) provided a
+;; scenario where we would need to respect the <contents> tag.
+
+;; Jean Magnan de Bornier (jean AT bornier DOT net) provided the
+;; markup string for link-and-anchor.
+
+;; Jim Ottaway (j DOT ottaway AT lse DOT ac DOT uk) implemented slides
+;; and lecture notes.
+
 ;;; Code:
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -52,6 +61,16 @@
   :type 'string
   :group 'muse-latex)
 
+(defcustom muse-latex-pdf-program "pdflatex"
+  "The program that is called to generate PDF content from LaTeX content."
+  :type 'string
+  :group 'muse-latex)
+
+(defcustom muse-latex-pdf-cruft '(".aux" ".toc" ".out" ".log")
+  "Extensions of files to remove after generating PDF output successfully."
+  :type 'string
+  :group 'muse-latex)
+
 (defcustom muse-latex-header
   "\\documentclass{article}
 
@@ -61,8 +80,6 @@
 \\usepackage{hyperref}
 \\usepackage[pdftex]{graphicx}
 
-\\newcommand{\\comment}[1]{}
-
 \\begin{document}
 
 \\title{<lisp>(muse-publishing-directive \"title\")</lisp>}
@@ -72,12 +89,14 @@
 \\maketitle
 
 <lisp>(and muse-publish-generate-contents
+           (not muse-latex-permit-contents-tag)
            \"\\\\tableofcontents\n\\\\newpage\")</lisp>\n\n"
   "Header used for publishing LaTeX files.  This may be text or a filename."
   :type 'string
   :group 'muse-latex)
 
-(defcustom muse-latex-footer "\n\\end{document}\n"
+(defcustom muse-latex-footer "<lisp>(muse-latex-bibliography)</lisp>
+\\end{document}\n"
   "Footer used for publishing LaTeX files.  This may be text or a filename."
   :type 'string
   :group 'muse-latex)
@@ -100,6 +119,7 @@
 \\maketitle
 
 <lisp>(and muse-publish-generate-contents
+           (not muse-latex-permit-contents-tag)
            \"\\\\tableofcontents\n\\\\newpage\")</lisp>\n\n"
   "Header used for publishing LaTeX files (CJK).  This may be text or a
 filename."
@@ -114,26 +134,63 @@ filename."
   :type 'string
   :group 'muse-latex)
 
+(defcustom muse-latex-slides-header
+  "\\documentclass[ignorenonframetext]{beamer}
+
+\\usepackage[english]{babel}
+\\usepackage[latin1]{inputenc}
+\\usepackage[T1]{fontenc}
+\\usepackage{hyperref}
+
+\\begin{document}
+
+\\title{<lisp>(muse-publishing-directive \"title\")</lisp>}
+\\author{<lisp>(muse-publishing-directive \"author\")</lisp>}
+\\date{<lisp>(muse-publishing-directive \"date\")</lisp>}
+
+\\maketitle
+
+<lisp>(and muse-publish-generate-contents
+           \"\\\\tableofcontents\n\\\\newpage\")</lisp>\n\n"
+  "Header for publishing of slides using LaTeX.
+This may be text or a filename.
+
+You must have the Beamer extension for LaTeX installed for this to work."
+  :type 'string
+  :group 'muse-latex)
+
+(defcustom muse-latex-lecture-notes-header
+  "\\documentclass{article}
+\\usepackage{beamerarticle}
+
+\\usepackage[english]{babel}
+\\usepackage[latin1]{inputenc}
+\\usepackage[T1]{fontenc}
+\\usepackage{hyperref}
+
+\\begin{document}
+
+\\title{<lisp>(muse-publishing-directive \"title\")</lisp>}
+\\author{<lisp>(muse-publishing-directive \"author\")</lisp>}
+\\date{<lisp>(muse-publishing-directive \"date\")</lisp>}
+
+\\maketitle
+
+<lisp>(and muse-publish-generate-contents
+           \"\\\\tableofcontents\n\\\\newpage\")</lisp>\n\n"
+  "Header for publishing of lecture notes using LaTeX.
+This may be text or a filename.
+
+You must have the Beamer extension for LaTeX installed for this to work."
+  :type 'string
+  :group 'muse-latex)
+
 (defcustom muse-latex-markup-regexps
   `(;; numeric ranges
     (10000 "\\([0-9]+\\)-\\([0-9]+\\)" 0 "\\1--\\2")
 
-    ;; characters which need quoting
-    (10010 "\\([$#%]\\)" 0 "\\\\\\1")
-    (10020 "_" 0 "\\\\textunderscore{}")
-    (10030 "<" 0 "\\\\textless{}")
-    (10040 ">" 0 "\\\\textgreater{}")
-    (10050 "\\^" 0 "\\\\^{}")
-
     ;; be careful of closing quote pairs
-    (10100 "\"'" 0 "\"\\\\-'")
-
-    ;; join together the parts of a list or table
-    (10200 ,(concat
-             "\\\\end{\\(tabular\\|description\\|itemize\\|enumerate\\)}"
-             "\\([" muse-regexp-blank "]*\n\\)\\{0,2\\}"
-             "[" muse-regexp-blank "]*"
-             "\\\\begin{\\1}\\({[^\n}]+}\\)?\n+") 0 ""))
+    (10100 "\"'" 0 "\"\\\\-'"))
   "List of markup regexps for identifying regions in a Muse page.
 For more on the structure of this list, see `muse-publish-markup-regexps'."
   :type '(repeat (choice
@@ -146,8 +203,7 @@ For more on the structure of this list, see `muse-publish-markup-regexps'."
   :group 'muse-latex)
 
 (defcustom muse-latex-markup-functions
-  '((anchor . muse-latex-markup-anchor)
-    (table . muse-latex-markup-table))
+  '((table . muse-latex-markup-table))
   "An alist of style types to custom functions for that kind of text.
 For more on the structure of this list, see
 `muse-publish-markup-functions'."
@@ -155,16 +211,25 @@ For more on the structure of this list, see
   :group 'muse-latex)
 
 (defcustom muse-latex-markup-strings
-  '((image-with-desc . "\\includegraphics[width=\\textwidth]{%s}")
-    (image-link      . "\\includegraphics[width=\\textwidth]{%s}")
-    (url-with-image  . "%% %s\n\\includegraphics[width=\\textwidth]{%s}")
-    (url-link        . "\\href{%s}{%s}")
-    (internal-link   . "\\hyperlink{%s}{%s}")
+  '((image-with-desc . "\\begin{figure}[h]
+\\centering\\includegraphics[width=0.75\\textwidth]{%s.%s}
+\\caption{%s}
+\\end{figure}")
+    (image           . "\\begin{figure}[h]
+\\centering\\includegraphics[width=0.75\\textwidth]{%s.%s}
+\\end{figure}")
+    (image-link      . "%% %s
+\\includegraphics[width=0.75\\textwidth]{%s.%s}")
+    (anchor-ref      . "\\ref{%s}")
+    (url             . "\\url{%s}")
+    (url-and-desc    . "\\href{%s}{%s}\\footnote{%1%}")
+    (link            . "\\href{%s}{%s}\\footnote{%1%}")
+    (link-and-anchor . "\\href{%1%}{%3%}\\footnote{%1%}")
     (email-addr      . "\\verb|%s|")
+    (anchor          . "\\label{%s}")
     (emdash          . "---")
-    (comment-begin   . "\\comment{")
-    (comment-end     . "}")
-    (rule            . "\\bigskip")
+    (comment-begin   . "% ")
+    (rule            . "\\vspace{.5cm}\\hrule\\vspace{.5cm}")
     (no-break-space  . "~")
     (enddots         . "\\ldots{}")
     (dots            . "\\dots{}")
@@ -203,19 +268,36 @@ For more on the structure of this list, see
     (end-center      . "\n\\end{center}")
     (begin-quote     . "\\begin{quote}\n")
     (end-quote       . "\n\\end{quote}")
-    (begin-uli       . "\\begin{itemize}\n\\item ")
+    (begin-cite     . "\\cite{")
+    (begin-cite-author . "\\citet{")
+    (begin-cite-year . "\\citet{")
+    (end-cite        . "}")
+    (begin-uli       . "\\begin{itemize}\n")
     (end-uli         . "\n\\end{itemize}")
-    (begin-oli       . "\\begin{enumerate}\n\\item ")
+    (begin-uli-item  . "\\item ")
+    (begin-oli       . "\\begin{enumerate}\n")
     (end-oli         . "\n\\end{enumerate}")
-    (begin-ddt       . "\\begin{description}\n\\item[")
-    (start-dde       . "] ")
-    (end-ddt         . "\\end{description}"))
+    (begin-oli-item  . "\\item ")
+    (begin-dl        . "\\begin{description}\n")
+    (end-dl          . "\n\\end{description}")
+    (begin-ddt       . "\\item[")
+    (end-ddt         . "] \\mbox{}\n"))
   "Strings used for marking up text.
 These cover the most basic kinds of markup, the handling of which
 differs little between the various styles."
   :type '(alist :key-type symbol :value-type string)
   :group 'muse-latex)
 
+(defcustom muse-latex-slides-markup-tags
+  '(("slide" t t nil muse-latex-slide-tag))
+ "A list of tag specifications, for specially marking up LaTeX slides."
+  :type '(repeat (list (string :tag "Markup tag")
+                       (boolean :tag "Expect closing tag" :value t)
+                       (boolean :tag "Parse attributes" :value nil)
+                       (boolean :tag "Nestable" :value nil)
+                       function))
+  :group 'muse-latex)
+
 (defcustom muse-latexcjk-encoding-map
   '((utf-8              . "{UTF8}{song}")
     (japanese-iso-8bit  . "[dnp]{JIS}{min}")
@@ -248,13 +330,37 @@ system to an associated CJK coding system."
         (cdr match)
       muse-latexcjk-encoding-default)))
 
-(defcustom muse-latex-markup-specials
-  '((?\\ . "\\\\"))
-  "A table of characters which must be represented specially."
+(defcustom muse-latex-markup-specials-document
+  '((?\\ . "\\textbackslash{}")
+    (?\_ . "\\textunderscore{}")
+    (?\< . "\\textless{}")
+    (?\> . "\\textgreater{}")
+    (?^  . "\\^{}")
+    (?\~ . "\\~{}")
+    (?\@ . "\\@")
+    (?\$ . "\\$")
+    (?\% . "\\%")
+    (?\{ . "\\{")
+    (?\} . "\\}")
+    (?\& . "\\&")
+    (?\# . "\\#"))
+  "A table of characters which must be represented specially.
+These are applied to the entire document, sans already-escaped
+regions."
   :type '(alist :key-type character :value-type string)
   :group 'muse-latex)
 
-(defcustom muse-latex-markup-texttt-specials
+(defcustom muse-latex-markup-specials-example
+  '()
+  "A table of characters which must be represented specially.
+These are applied to <example> regions.
+
+With the default interpretation of <example> regions, no specials
+need to be escaped."
+  :type '(alist :key-type character :value-type string)
+  :group 'muse-latex)
+
+(defcustom muse-latex-markup-specials-literal
   '((?\n . "\\\n")
     (?_  . "\\textunderscore{}")
     (?\< . "\\textless{}")
@@ -268,57 +374,119 @@ system to an associated CJK coding system."
     (?\& . "\\&")
     (?\# . "\\#"))
   "A table of characters which must be represented specially.
-This applies to text in \\texttt{} regions."
+This applies to =monospaced text= and <code> regions."
   :type '(alist :key-type character :value-type string)
   :group 'muse-latex)
 
-(defun muse-latex-insert-anchor (anchor)
-  "Insert an anchor, either around the word at point, or within a tag.
-If the anchor occurs at the end of a line, ignore it."
-  (unless (or (bolp)  ; point is placed after newline if anchor at end
-              (get-text-property (match-end 1) 'noemphasis))
-    (skip-chars-forward (concat muse-regexp-blank "\n"))
-    (if (looking-at "<\\([^ />]+\\)>")
-        (let ((tag (match-string 1)))
-          (goto-char (match-end 0))
-          (insert "\\hypertarget{" anchor "}{")
-          (or (and (search-forward (format "</%s>" tag)
-                                   (muse-line-end-position) t)
-                   (goto-char (match-beginning 0)))
-              (forward-word 1))
-          (insert "}"))
-      (insert "\\hypertarget{" anchor "}{")
-      (forward-word 1)
-      (insert "}"))))
+(defcustom muse-latex-markup-specials-url
+  '((?\\ . "\\textbackslash{}")
+    (?\_ . "\\_")
+    (?\< . "\\<")
+    (?\> . "\\>")
+    (?\$ . "\\$")
+    (?\% . "\\%")
+    (?\{ . "\\{")
+    (?\} . "\\}")
+    (?\& . "\\&")
+    (?\# . "\\#"))
+  "A table of characters which must be represented specially.
+These are applied to URLs."
+  :type '(alist :key-type character :value-type string)
+  :group 'muse-latex)
 
-(defun muse-latex-markup-anchor ()
-  (save-match-data
-    (muse-latex-insert-anchor (match-string 1)))
-  (match-string 1))
+(defcustom muse-latex-markup-specials-image
+  '((?\\ . "\\textbackslash{}")     ; cannot find suitable replacement
+    (?\< . "\\<")
+    (?\> . "\\>")
+    (?\$ . "\\$")
+    (?\% . "\\%")
+    (?\{ . "\\{")
+    (?\} . "\\}")
+    (?\& . "\\&")
+    (?\# . "\\#")                   ; cannot find suitable replacement
+    )
+  "A table of characters which must be represented specially.
+These are applied to image filenames."
+  :type '(alist :key-type character :value-type string)
+  :group 'muse-latex)
+
+(defun muse-latex-decide-specials (context)
+  "Determine the specials to escape, depending on CONTEXT."
+  (cond ((memq context '(underline emphasis document url-desc verbatim))
+         muse-latex-markup-specials-document)
+        ((eq context 'image)
+         muse-latex-markup-specials-image)
+        ((memq context '(email url))
+         muse-latex-markup-specials-url)
+        ((eq context 'literal)
+         muse-latex-markup-specials-literal)
+        ((eq context 'example)
+         muse-latex-markup-specials-example)
+        (t (error "Invalid context '%s' in muse-latex" context))))
+
+(defcustom muse-latex-permit-contents-tag nil
+  "If nil, ignore <contents> tags.  Otherwise, insert table of contents.
+
+Most of the time, it is best to have a table of contents on the
+first page, with a new page immediately following.  To make this
+work with documents published in both HTML and LaTeX, we need to
+ignore the <contents> tag.
+
+If you don't agree with this, then set this option to non-nil,
+and it will do what you expect."
+  :type 'boolean
+  :group 'muse-latex)
 
 (defun muse-latex-markup-table ()
-  (let* ((str (prog1
-                  (match-string 1)
-                (delete-region (match-beginning 0) (match-end 0))))
-         (fields (split-string str "\\s-*|+\\s-*"))
-         (type (and (string-match "\\s-*\\(|+\\)\\s-*" str)
-                    (length (match-string 1 str)))))
-    (insert "\\begin{tabular}{" (make-string (length fields) ?l) "}\n")
-    (when (= type 3)
-      (insert "\\hline\n"))
-    (insert (mapconcat 'identity fields " & "))
-    (insert " \\\\\n")
-    (when (= type 2)
-      (insert "\\hline\n"))
-    (insert "\\end{tabular}")))
+  (let* ((table-info (muse-publish-table-fields (match-beginning 0)
+                                                (match-end 0)))
+         (row-len (car table-info))
+         (field-list (cdr table-info)))
+    (when table-info
+      (muse-insert-markup "\\begin{tabular}{" (make-string row-len ?l) "}\n")
+      (dolist (fields field-list)
+        (let ((type (car fields)))
+          (setq fields (cdr fields))
+          (if (eq type 'hline)
+              (muse-insert-markup "\\hline\n")
+            (when (= type 3)
+              (muse-insert-markup "\\hline\n"))
+            (insert (car fields))
+            (setq fields (cdr fields))
+            (dolist (field fields)
+              (muse-insert-markup " & ")
+              (insert field))
+            (muse-insert-markup " \\\\\n")
+            (when (= type 2)
+              (muse-insert-markup "\\hline\n")))))
+      (muse-insert-markup "\\end{tabular}"))))
+
+;;; Tags for LaTeX
+
+(defun muse-latex-slide-tag (beg end attrs)
+  "Publish the <slide> tag in LaTeX.
+This is used by the slides and lecture-notes publishing styles."
+  (let ((title (cdr (assoc "title" attrs))))
+    (goto-char beg)
+    (muse-insert-markup "\\begin{frame}\n")
+    (when title
+      (muse-insert-markup "\\frametitle{")
+      (insert title)
+      (muse-insert-markup "}\n"))
+    (goto-char end)
+    (muse-insert-markup "\n\\end{frame}")))
+
+;;; Post-publishing functions
 
 (defun muse-latex-fixup-dquotes ()
   "Fixup double quotes."
+  (goto-char (point-min))
   (let ((open t))
     (while (search-forward "\"" nil t)
       (unless (get-text-property (match-beginning 0) 'read-only)
-        (if (and (bolp) (eq (char-before) ?\n))
-            (setq open t))
+        (when (or (bobp)
+                  (eq (char-before) ?\n))
+          (setq open t))
         (if open
             (progn
               (replace-match "``")
@@ -326,41 +494,66 @@ If the anchor occurs at the end of a line, ignore it."
           (replace-match "''")
           (setq open t))))))
 
-(defun muse-latex-fixup-texttt ()
-  "Escape extra characters in texttt sections."
-  (let ((inhibit-read-only t)
-        beg end)
-    (while (and (< (point) (point-max))
-                (setq beg (search-forward "\\texttt{" nil t)))
-      (goto-char (next-single-property-change (point) 'read-only))
-      (backward-char)
-      (setq end (point-marker))
-      (goto-char beg)
-      (while (< (point) end)
-        (let ((repl (assoc (char-after) muse-latex-markup-texttt-specials)))
-          (if (null repl)
-              (forward-char 1)
-            (delete-char 1)
-            (insert-before-markers (cdr repl))))))))
+(defun muse-latex-fixup-citations ()
+  "Replace semicolons in multi-head citations with colons."
+  (goto-char (point-min))
+  (while (re-search-forward "\\\\cite.?{" nil t)
+    (let ((start (point))
+          (end (re-search-forward "}")))
+      (save-restriction
+        (narrow-to-region start end)
+        (goto-char (point-min))
+        (while (re-search-forward ";" nil t)
+          (replace-match ","))))))
 
-(defun muse-latex-finalize-buffer ()
+(defun muse-latex-fixup-headings ()
+  "Remove footnotes in headings, since LaTeX does not permit them to exist.
+
+This can happen if there is a link in a heading, because by
+default Muse will add a footnote for each link."
   (goto-char (point-min))
+  (while (re-search-forward "^\\\\section.?{" nil t)
+    (save-restriction
+      (narrow-to-region (match-beginning 0) (muse-line-end-position))
+      (goto-char (point-min))
+      (while (re-search-forward "\\\\footnote{[^}\n]+}" nil t)
+        (replace-match ""))
+      (forward-line 1))))
+
+(defun muse-latex-munge-buffer ()
   (muse-latex-fixup-dquotes)
-  (goto-char (point-min))
-  (muse-latex-fixup-texttt))
+  (muse-latex-fixup-citations)
+  (muse-latex-fixup-headings)
+  (when (and muse-latex-permit-contents-tag
+             muse-publish-generate-contents)
+    (goto-char (car muse-publish-generate-contents))
+    (muse-insert-markup "\\tableofcontents")))
+
+(defun muse-latex-bibliography ()
+  (save-excursion
+    (goto-char (point-min))
+    (if (re-search-forward "\\\\cite.?{" nil t)
+        (concat
+         "\\bibliography{"
+         (muse-publishing-directive "bibsource")
+         "}\n")
+      "")))
 
 (defun muse-latex-pdf-browse-file (file)
   (shell-command (concat "open " file)))
 
 (defun muse-latex-pdf-generate (file output-path final-target)
-  (muse-publish-transform-output
+  (apply
+   #'muse-publish-transform-output
    file output-path final-target "PDF"
    (function
     (lambda (file output-path)
-      (let ((command (format "cd \"%s\"; pdflatex \"%s\""
-                             (file-name-directory output-path) file))
-            (times 0)
-            result)
+      (let* ((fnd (file-name-directory output-path))
+             (command (format "cd \"%s\"; %s \"%s\""
+                              fnd muse-latex-pdf-program
+                              (file-relative-name file fnd)))
+             (times 0)
+             result)
         ;; XEmacs can sometimes return a non-number result.  We'll err
         ;; on the side of caution by continuing to attempt to generate
         ;; the PDF if this happens and treat the final result as
@@ -378,35 +571,50 @@ If the anchor occurs at the end of a line, ignore it."
                 (eq result 0))
             t
           nil))))
-   ".aux" ".toc" ".out" ".log"))
+   muse-latex-pdf-cruft))
 
-(unless (assoc "latex" muse-publishing-styles)
-  (muse-define-style "latex"
-                     :suffix    'muse-latex-extension
-                     :regexps   'muse-latex-markup-regexps
-                     :functions 'muse-latex-markup-functions
-                     :strings   'muse-latex-markup-strings
-                     :specials  'muse-latex-markup-specials
-                     :after     'muse-latex-finalize-buffer
-                     :header    'muse-latex-header
-                     :footer    'muse-latex-footer
-                     :browser   'find-file)
+;;; Register the Muse LATEX Publishers
 
-  (muse-derive-style "pdf" "latex"
-                     :final   'muse-latex-pdf-generate
-                     :browser 'muse-latex-pdf-browse-file
-                     :link-suffix 'muse-latex-pdf-extension
-                     :osuffix 'muse-latex-pdf-extension)
+(muse-define-style "latex"
+                   :suffix    'muse-latex-extension
+                   :regexps   'muse-latex-markup-regexps
+                   :functions 'muse-latex-markup-functions
+                   :strings   'muse-latex-markup-strings
+                   :specials  'muse-latex-decide-specials
+                   :before-end 'muse-latex-munge-buffer
+                   :header    'muse-latex-header
+                   :footer    'muse-latex-footer
+                   :browser   'find-file)
 
-  (muse-derive-style "latexcjk" "latex"
-                     :header    'muse-latexcjk-header
-                     :footer    'muse-latexcjk-footer)
+(muse-derive-style "pdf" "latex"
+                   :final   'muse-latex-pdf-generate
+                   :browser 'muse-latex-pdf-browse-file
+                   :link-suffix 'muse-latex-pdf-extension
+                   :osuffix 'muse-latex-pdf-extension)
 
-  (muse-derive-style "pdfcjk" "latexcjk"
-                     :final   'muse-latex-pdf-generate
-                     :browser 'muse-latex-pdf-browse-file
-                     :link-suffix 'muse-latex-pdf-extension
-                     :osuffix 'muse-latex-pdf-extension))
+(muse-derive-style "latexcjk" "latex"
+                   :header    'muse-latexcjk-header
+                   :footer    'muse-latexcjk-footer)
+
+(muse-derive-style "pdfcjk" "latexcjk"
+                   :final   'muse-latex-pdf-generate
+                   :browser 'muse-latex-pdf-browse-file
+                   :link-suffix 'muse-latex-pdf-extension
+                   :osuffix 'muse-latex-pdf-extension)
+
+(muse-derive-style "slides" "latex"
+                   :header 'muse-latex-slides-header
+                   :tags   'muse-latex-slides-markup-tags)
+
+(muse-derive-style "slides-pdf" "pdf"
+                   :header 'muse-latex-slides-header
+                   :tags   'muse-latex-slides-markup-tags)
+
+(muse-derive-style "lecture-notes" "slides"
+                   :header 'muse-latex-lecture-notes-header)
+
+(muse-derive-style "lecture-notes-pdf" "slides-pdf"
+                   :header 'muse-latex-lecture-notes-header)
 
 (provide 'muse-latex)
 
