@@ -6,7 +6,7 @@
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -143,6 +143,8 @@ index at intervals."
 
     map))
 
+;;; Muse mode
+
 (defvar muse-mode-map
   (let ((map (make-sparse-keymap)))
     (define-key map [(control ?c) (control ?a)] 'muse-index)
@@ -197,8 +199,6 @@ index at intervals."
     map)
   "Keymap used by Emacs Muse mode.")
 
-;; Code:
-
 ;;;###autoload
 (define-derived-mode muse-mode text-mode "Muse"
   "Muse is an Emacs mode for authoring and publishing documents.
@@ -225,18 +225,20 @@ index at intervals."
       (add-to-list 'fill-nobreak-predicate
                    'muse-mode-fill-nobreak-p)))
   ;; Make fill work nicely with item lists
-  (set (make-local-variable 'adaptive-fill-regexp)
-       (concat "\\s-+\\(-\\|[0-9]+\\.\\)\\s-+\\|\\[[0-9]+\\]\\s-*"
-               "\\|.*\\s-*::\\s-+\\|\\s-*"))
-  (set (make-local-variable 'paragraph-start)
-       (concat paragraph-start
-               "\\|\\s-+\\(-\\|[0-9]+\\.\\)\\s-+\\|\\[[0-9]+\\]\\s-*"
-               "\\|.*\\s-*::\\s-+"))
+  (let ((regexp (concat "\\s-+\\(-\\|[0-9]+\\.\\)\\s-+"
+                        "\\|\\[[0-9]+\\]\\s-*"
+                        "\\|.*\\s-*::\\s-+")))
+    (set (make-local-variable 'adaptive-fill-regexp)
+         (concat regexp "\\|\\s-*"))
+    (set (make-local-variable 'paragraph-start)
+         (concat paragraph-start "\\|" regexp)))
   ;; Comment syntax is `; comment'
   (set (make-local-variable 'comment-start)
        "; ")
   (set (make-local-variable 'comment-start-skip)
        "^;\\s-+")
+  (set (make-local-variable 'indent-line-function)
+       #'ignore)
   ;; If we're using Emacs21, this makes flyspell work like it should
   (when (boundp 'flyspell-generic-check-word-p)
     (set (make-local-variable 'flyspell-generic-check-word-p)
@@ -301,13 +303,13 @@ This is used to keep links from being improperly colorized by flyspell."
   "See if point is on a blank line"
   (save-excursion
     (beginning-of-line)
-    (looking-at (concat "[" muse-regexp-blank "]?[\n]+"))))
+    (looking-at (concat "[" muse-regexp-blank "]*$"))))
 
 (defun muse-get-paragraph-start ()
   "Return the start of the current paragraph. This function will
 return nil if there are no prior paragraphs and the beginning of
 the line if point is on a blank line."
-  (let ((para-start (concat "[\n]+[" muse-regexp-blank "]?[\n]+")))
+  (let ((para-start (concat "^[" muse-regexp-blank "]*$")))
     ;; search back to start of paragraph
     (save-excursion
       (save-match-data
@@ -578,9 +580,11 @@ in `muse-project-alist'."
                                             (cddr muse-current-project))
          current-prefix-arg))
   (setq style (muse-style style))
-  (let ((result-path
-         (muse-publish-output-file buffer-file-name
-                                   (muse-style-element :path style) style)))
+  (let* ((output-dir (muse-style-element :path style))
+         (result-path (muse-publish-output-file buffer-file-name output-dir
+                                                style))
+         (muse-current-output-style (list :base (car style)
+                                          :path output-dir)))
     (if (not (file-readable-p result-path))
         (error "Cannot open output file '%s'" result-path)
       (if other-window
@@ -722,16 +726,19 @@ GREP-COMMAND if passed will supplant `muse-grep-command'."
                             (shell-quote-argument
                              (expand-file-name dir)))
                           muse-directories " ")))
-    (while (string-match "%W" str)
-      (setq str (replace-match string t t str)))
-    (while (string-match "%D" str)
-      (setq str (replace-match dirs t t str)))
-    (if (fboundp 'compilation-start)
-        (compilation-start str nil (lambda (&rest args) "*search*")
-                           grep-regexp-alist)
-      (and (fboundp 'compile-internal)
-           (compile-internal str "No more search hits" "search"
-                             nil grep-regexp-alist)))))
+    (if (string= dirs "")
+        (muse-display-warning
+         "No directories were found in the current project; aborting search")
+      (while (string-match "%W" str)
+        (setq str (replace-match string t t str)))
+      (while (string-match "%D" str)
+        (setq str (replace-match dirs t t str)))
+      (if (fboundp 'compilation-start)
+          (compilation-start str nil (lambda (&rest args) "*search*")
+                             grep-regexp-alist)
+        (and (fboundp 'compile-internal)
+             (compile-internal str "No more search hits" "search"
+                               nil grep-regexp-alist))))))
 
 ;;;###autoload
 (defun muse-search-with-command (text)
@@ -821,7 +828,8 @@ function, you might want to set this manually.")
   "Insert a tag interactively with a blank line after it."
   (interactive
    (list
-    (completing-read
+    (funcall
+     muse-completing-read-function
      (concat "Tag: "
              (when muse-tag-history
                (concat "(default: " (car muse-tag-history) ") ")))
@@ -851,4 +859,109 @@ function, you might want to set this manually.")
       (insert (concat "\n\n</" tag ">\n"))
       (forward-line -2))))
 
+;;; Muse list edit minor mode
+
+(defvar muse-list-edit-minor-mode-map
+  (let ((map (make-sparse-keymap)))
+    (define-key map [(meta return)] 'muse-l-e-m-m-insert-list-item)
+    (define-key map [(control ?>)] 'muse-l-e-m-m-increase-list-item-indent)
+    (define-key map [(control ?<)] 'muse-l-e-m-m-decrease-list-item-indent)
+
+    map)
+  "Keymap used by Muse list edit minor mode.")
+
+(defvar muse-l-e-m-m-list-item-regexp
+  (concat "^%s\\(\\([^\n" muse-regexp-blank "].*?\\)?::"
+          "\\(?:[" muse-regexp-blank "]+\\|$\\)"
+          "\\|[" muse-regexp-blank "]?[-*+][" muse-regexp-blank "]*"
+          "\\|[" muse-regexp-blank "][0-9]+\\.[" muse-regexp-blank "]*\\)")
+  "Regexp used to match the beginning of a list item.
+This is used by `muse-list-edit-minor-mode'.
+The '%s' will be replaced with a whitespace regexp when publishing.")
+
+(defun muse-l-e-m-m-insert-list-item ()
+  "Insert a list item at the current point, taking into account
+your current list type and indentation level."
+  (interactive)
+  (let ((muse-list-item-regexp muse-l-e-m-m-list-item-regexp))
+    (call-interactively 'muse-insert-list-item)))
+
+(defun muse-l-e-m-m-increase-list-item-indent ()
+  "Increase the indentation of the current list item."
+  (interactive)
+  (let ((muse-list-item-regexp muse-l-e-m-m-list-item-regexp))
+    (call-interactively 'muse-increase-list-item-indentation)))
+
+(defun muse-l-e-m-m-decrease-list-item-indent ()
+  "Decrease the indentation of the current list item."
+  (interactive)
+  (let ((muse-list-item-regexp muse-l-e-m-m-list-item-regexp))
+    (call-interactively 'muse-decrease-list-item-indentation)))
+
+(defvar muse-l-e-m-m-data nil
+  "A list of data that was changed by Muse list edit minor mode.")
+(make-variable-buffer-local 'muse-l-e-m-m-data)
+
+;;;###autoload
+(define-minor-mode muse-list-edit-minor-mode
+  "This is a global minor mode for editing files with lists.
+It is meant to be used with other major modes, and not with Muse mode.
+
+Interactively, with no prefix argument, toggle the mode.
+With universal prefix ARG turn mode on.
+With zero or negative ARG turn mode off.
+
+This minor mode provides the Muse keybindings for editing lists,
+and support for filling lists properly.
+
+It recognizes not only Muse-style lists, which use the \"-\"
+character or numbers, but also lists that use asterisks or plus
+signs.  This should make the minor mode generally useful.
+
+Definition lists and footnotes are also recognized.
+
+Note that list items may omit leading spaces, for compatibility
+with modes that set `left-margin', such as
+`debian-changelog-mode'.
+
+\\{muse-list-edit-minor-mode-map}"
+  :init-value nil
+  :lighter ""
+  :keymap muse-list-edit-minor-mode-map
+  :global nil
+  :group 'muse-mode
+  (if (not muse-list-edit-minor-mode)
+      ;; deactivate
+      (when muse-l-e-m-m-data
+        (setq adaptive-fill-regexp (cdr (assoc "a-f-r" muse-l-e-m-m-data))
+              paragraph-start (cdr (assoc "p-s" muse-l-e-m-m-data))
+              fill-prefix (cdr (assoc "f-p" muse-l-e-m-m-data)))
+        (setq muse-l-e-m-m-data nil))
+    ;; activate
+    (unless muse-l-e-m-m-data
+      ;; save previous fill-related data so we can restore it later
+      (setq muse-l-e-m-m-data
+            (list (cons "a-f-r" adaptive-fill-regexp)
+                  (cons "p-s" paragraph-start)
+                  (cons "f-p" fill-prefix))))
+    ;; make fill work nicely with item lists
+    (let ((regexp (concat "\\s-*\\([-*+]\\|[0-9]+\\.\\)\\s-+"
+                          "\\|\\[[0-9]+\\]\\s-*"
+                          "\\|.*\\s-*::\\s-+")))
+      (set (make-local-variable 'adaptive-fill-regexp)
+           (concat regexp "\\|\\s-*"))
+      (set (make-local-variable 'paragraph-start)
+           (concat paragraph-start "\\|" regexp)))
+    ;; force fill-prefix to be nil, because if it is a string that has
+    ;; initial spaces, it messes up fill-paragraph's algorithm
+    (set (make-local-variable 'fill-prefix) nil)))
+
+(defun turn-on-muse-list-edit-minor-mode ()
+  "Unconditionally turn on Muse list edit minor mode."
+  (muse-list-edit-minor-mode 1))
+
+(defun turn-off-muse-list-edit-minor-mode ()
+  "Unconditionally turn off Muse list edit minor mode."
+  (muse-list-edit-minor-mode -1))
+
 ;;; muse-mode.el ends here
