@@ -6,7 +6,7 @@
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -436,58 +436,59 @@ On UNIX, this list is only updated if one of the directories'
 contents have changed.  On Windows, it is always reread from
 disk."
   (setq project (muse-project project))
-  (let* ((file-alist (assoc (car project) muse-project-file-alist))
-         (last-mod (cdr (cdr file-alist))))
-    ;; Determine the last modified of any directory mentioned in the
-    ;; project's pattern list
-    (unless (or muse-under-windows-p no-check-p)
-      (let ((pats (cadr project)))
-        (while pats
-          (if (symbolp (car pats))
-              (setq pats (cddr pats))
-            (let* ((fnd (file-name-directory (car pats)))
-                   (dir (cond ((file-directory-p (car pats))
-                               (car pats))
-                              ((and (not (file-readable-p (car pats)))
-                                    fnd
-                                    (file-directory-p fnd))
-                               fnd))))
-              (when dir
-                (let ((mod-time (nth 5 (file-attributes dir))))
-                  (when (or (null last-mod)
-                            (and mod-time
-                                 (muse-time-less-p last-mod mod-time)))
-                    (setq last-mod mod-time)))))
-            (setq pats (cdr pats))))))
-    ;; Either return the currently known list, or read it again from
-    ;; disk
-    (if (or (and no-check-p (cadr file-alist))
-            muse-updating-file-alist-p
-            (not (or muse-under-windows-p
-                     (null (cddr file-alist))
-                     (null last-mod)
-                     (muse-time-less-p (cddr file-alist) last-mod))))
-        (cadr file-alist)
-      (if file-alist
-          (setcdr (cdr file-alist) last-mod)
-        (setq file-alist (cons (car project) (cons nil last-mod))
-              muse-project-file-alist
-              (cons file-alist muse-project-file-alist)))
-      ;; Read in all of the file entries
-      (let ((muse-updating-file-alist-p t))
-        (prog1
-            (save-match-data
-              (setcar
-               (cdr file-alist)
-               (let* ((names (list t))
-                      (pats (cadr project)))
-                 (while pats
-                   (if (symbolp (car pats))
-                       (setq pats (cddr pats))
-                     (nconc names (muse-project-file-entries (car pats)))
-                     (setq pats (cdr pats))))
-                 (cdr names))))
-          (run-hooks 'muse-project-file-alist-hook))))))
+  (when (and project muse-project-alist)
+    (let* ((file-alist (assoc (car project) muse-project-file-alist))
+           (last-mod (cdr (cdr file-alist))))
+      ;; Determine the last modified of any directory mentioned in the
+      ;; project's pattern list
+      (unless (or muse-under-windows-p no-check-p)
+        (let ((pats (cadr project)))
+          (while pats
+            (if (symbolp (car pats))
+                (setq pats (cddr pats))
+              (let* ((fnd (file-name-directory (car pats)))
+                     (dir (cond ((file-directory-p (car pats))
+                                 (car pats))
+                                ((and (not (file-readable-p (car pats)))
+                                      fnd
+                                      (file-directory-p fnd))
+                                 fnd))))
+                (when dir
+                  (let ((mod-time (nth 5 (file-attributes dir))))
+                    (when (or (null last-mod)
+                              (and mod-time
+                                   (muse-time-less-p last-mod mod-time)))
+                      (setq last-mod mod-time)))))
+              (setq pats (cdr pats))))))
+      ;; Either return the currently known list, or read it again from
+      ;; disk
+      (if (or (and no-check-p (cadr file-alist))
+              muse-updating-file-alist-p
+              (not (or muse-under-windows-p
+                       (null (cddr file-alist))
+                       (null last-mod)
+                       (muse-time-less-p (cddr file-alist) last-mod))))
+          (cadr file-alist)
+        (if file-alist
+            (setcdr (cdr file-alist) last-mod)
+          (setq file-alist (cons (car project) (cons nil last-mod))
+                muse-project-file-alist
+                (cons file-alist muse-project-file-alist)))
+        ;; Read in all of the file entries
+        (let ((muse-updating-file-alist-p t))
+          (prog1
+              (save-match-data
+                (setcar
+                 (cdr file-alist)
+                 (let* ((names (list t))
+                        (pats (cadr project)))
+                   (while pats
+                     (if (symbolp (car pats))
+                         (setq pats (cddr pats))
+                       (nconc names (muse-project-file-entries (car pats)))
+                       (setq pats (cdr pats))))
+                   (cdr names))))
+            (run-hooks 'muse-project-file-alist-hook)))))))
 
 (defun muse-project-of-file (&optional pathname)
   "Determine which project the given PATHNAME relates to.
@@ -497,6 +498,7 @@ If PATHNAME is nil, the current buffer's filename is used."
     (unless pathname (setq pathname (muse-current-file)))
     (save-match-data
       (when (and (stringp pathname)
+                 muse-project-alist
                  (not (string= pathname ""))
                  (not (let ((case-fold-search nil))
                         (or (string-match muse-project-ignore-regexp
@@ -506,21 +508,25 @@ If PATHNAME is nil, the current buffer's filename is used."
                                            pathname))))))
         (let* ((file (file-truename pathname))
                (dir  (file-name-directory file))
-               (project-entry muse-project-alist)
-               found)
-          (while (and project-entry (not found))
-            (let ((pats (car (cdar project-entry))))
-              (while (and pats (not found))
-                (if (symbolp (car pats))
-                    (setq pats (cddr pats))
-                  (let ((truename (file-truename (car pats))))
-                    (if (or (string= truename file)
-                            (string= truename dir)
-                            (string-match (regexp-quote truename) file))
-                        (setq found (car project-entry))))
-                  (setq pats (cdr pats))))
-              (setq project-entry (cdr project-entry))))
-          found)))))
+               found rating matches)
+          (catch 'found
+            (dolist (project-entry muse-project-alist)
+              (let ((pats (cadr project-entry)))
+                (while pats
+                  (if (symbolp (car pats))
+                      (setq pats (cddr pats))
+                    (let ((tname (file-truename (car pats))))
+                      (cond ((or (string= tname file)
+                                 (string= tname dir))
+                             (throw 'found project-entry))
+                            ((string-match (concat "\\`" (regexp-quote tname))
+                                           file)
+                             (setq matches (cons (cons (match-end 0)
+                                                       project-entry)
+                                                 matches)))))
+                    (setq pats (cdr pats))))))
+            ;; if we haven't found an exact match, pick a candidate
+            (car (muse-sort-by-rating matches))))))))
 
 (defun muse-project-after-save-hook ()
   "Update Muse's file-alist if we are saving a Muse file."
@@ -540,15 +546,17 @@ If PATHNAME is nil, the current buffer's filename is used."
         (if (and (not no-assume)
                  (= 1 (length muse-project-alist)))
             (car muse-project-alist)
-          (assoc (completing-read prompt muse-project-alist)
+          (assoc (funcall muse-completing-read-function
+                          prompt muse-project-alist)
                  muse-project-alist)))))
 
 (defvar muse-project-page-history nil)
 
 (defun muse-read-project-file (project prompt &optional default)
-  (let ((name (completing-read prompt (muse-project-file-alist project)
-                               nil nil nil 'muse-project-page-history
-                               default)))
+  (let ((name (funcall muse-completing-read-function
+                       prompt (muse-project-file-alist project)
+                       nil nil nil 'muse-project-page-history
+                       default)))
     (cons name (muse-project-page-file name project))))
 
 ;;;###autoload
@@ -625,7 +633,7 @@ return non-nil."
     (and (stringp link-suffix)
          (string= given-suffix link-suffix))))
 
-(defun muse-project-applicable-styles (file styles &optional ignore-regexp)
+(defun muse-project-applicable-styles (file styles)
   "Given STYLES, return a list of the ones that are considered for FILE.
 The name of a project may be used for STYLES."
   (when (stringp styles)
@@ -636,14 +644,13 @@ The name of a project may be used for STYLES."
         (let ((include-regexp (muse-style-element :include style))
               (exclude-regexp (muse-style-element :exclude style))
               (rating nil))
-          (when (and (or ignore-regexp
-                         (and (null include-regexp)
+          (when (and (or (and (null include-regexp)
                               (null exclude-regexp))
                          (if include-regexp
                              (setq rating (string-match include-regexp file))
                            (not (string-match exclude-regexp file))))
-                     (or (not (file-exists-p file))
-                         (not (muse-project-private-p file))))
+                     (file-exists-p file)
+                     (not (muse-project-private-p file)))
             (setq used-styles (cons (cons rating style) used-styles)))))
       (muse-sort-by-rating (nreverse used-styles)))))
 
@@ -655,15 +662,38 @@ The user is prompted if several styles are found."
              (cons (muse-get-keyword :base style) style))
            (muse-project-applicable-styles file styles))))
 
+(defun muse-project-resolve-directory (page local-style remote-style)
+  "Figure out the directory part of the path that provides a link to PAGE.
+LOCAL-STYLE is the style of the current Muse file, and
+REMOTE-STYLE is the style associated with PAGE.
+
+If REMOTE-STYLE has a :base-url element, concatenate it and PAGE.
+Otherwise, return a relative link."
+  (let ((prefix (muse-style-element :base-url remote-style)))
+    (if prefix
+        (concat prefix page)
+      (file-relative-name (expand-file-name
+                           (file-name-nondirectory page)
+                           (muse-style-element :path remote-style))
+                          (expand-file-name
+                           (muse-style-element :path local-style))))))
+
 (defun muse-project-resolve-link (page local-style remote-styles)
-  "Return a published relative link from the output path of one file
-to another file.
+  "Return a published link from the output path of one file to another file.
 
 The best match for PAGE is determined by comparing the link
 suffix of the given local style and that of the remote styles.
 
 The remote styles are usually populated by
-`muse-project-applicable-styles'."
+`muse-project-applicable-styles'.
+
+If no remote style is found, return PAGE verbatim
+
+If PAGE has a :base-url associated with it, return the
+concatenation of the :base-url value and PAGE.
+
+Otherwise, return a relative path from the directory of
+LOCAL-STYLE to the best directory among REMOTE-STYLES."
   (let ((link-suffix (or (muse-style-element :link-suffix local-style)
                          (muse-style-element :suffix local-style)))
         remote-style)
@@ -675,16 +705,10 @@ The remote styles are usually populated by
                           remote-styles)))
     (if (null remote-style)
         page
-      (muse-publish-link-file
-       (let ((prefix (muse-style-element :base-url remote-style)))
-         (if prefix
-             (concat prefix page)
-           (file-relative-name (expand-file-name
-                                (file-name-nondirectory page)
-                                (muse-style-element :path remote-style))
-                               (expand-file-name
-                                (muse-style-element :path local-style)))))
-       remote-style))))
+      (setq page (muse-project-resolve-directory
+                  page local-style remote-style))
+      (concat (file-name-directory page)
+              (muse-publish-link-name page remote-style)))))
 
 (defun muse-project-current-output-style (&optional file project)
   (or muse-current-output-style
@@ -709,8 +733,8 @@ The remote styles are usually populated by
   ;; publish the member file!
   (muse-publish-file file style output-dir force))
 
-(defun muse-project-publish-file (file styles &optional force ignore-regexp)
-  (setq styles (muse-project-applicable-styles file styles ignore-regexp))
+(defun muse-project-publish-file (file styles &optional force)
+  (setq styles (muse-project-applicable-styles file styles))
   (let (published)
     (dolist (style styles)
       (if (or (not (listp style))
@@ -733,42 +757,50 @@ prompting if more than one style applies.
 
 If FORCE is given, publish the file even if it is up-to-date."
   (interactive (list current-prefix-arg))
-  (let* ((style (muse-project-get-applicable-style
-                buffer-file-name (cddr muse-current-project)))
-         (output-dir (muse-style-element :path style)))
-    (unless (muse-publish-file buffer-file-name style output-dir force)
-      (message (concat "The published version is up-to-date; use"
-                       " C-u C-c C-t to force an update.")))))
+  (let ((muse-current-project (muse-project-of-file)))
+    (if (not muse-current-project)
+        ;; file is not part of a project, so fall back to muse-publish
+        (if (interactive-p) (call-interactively 'muse-publish-this-file)
+          (muse-publish-this-file nil nil force))
+      (let* ((style (muse-project-get-applicable-style
+                     buffer-file-name (cddr muse-current-project)))
+             (output-dir (muse-style-element :path style))
+             (muse-current-output-style (list :base (car style)
+                                              :path output-dir)))
+        (unless (muse-publish-file buffer-file-name style output-dir force)
+          (message (concat "The published version is up-to-date; use"
+                           " C-u C-c C-t to force an update.")))))))
 
 (defun muse-project-save-buffers (&optional project)
   (setq project (muse-project project))
-  (map-y-or-n-p
-   (function
-    (lambda (buffer)
-      (and (buffer-modified-p buffer)
-           (not (buffer-base-buffer buffer))
-           (or (buffer-file-name buffer)
-               (progn
-                 (set-buffer buffer)
-                 (and buffer-offer-save
-                      (> (buffer-size) 0))))
-           (with-current-buffer buffer
-             (let ((proj (muse-project-of-file)))
-               (and proj (string= (car proj)
-                                  (car project)))))
-           (if (buffer-file-name buffer)
-               (format "Save file %s? "
-                       (buffer-file-name buffer))
-             (format "Save buffer %s? "
-                     (buffer-name buffer))))))
-   (function
-    (lambda (buffer)
-      (set-buffer buffer)
-      (save-buffer)))
-   (buffer-list)
-   '("buffer" "buffers" "save")
-   (if (boundp 'save-some-buffers-action-alist)
-       save-some-buffers-action-alist)))
+  (when project
+    (map-y-or-n-p
+     (function
+      (lambda (buffer)
+        (and (buffer-modified-p buffer)
+             (not (buffer-base-buffer buffer))
+             (or (buffer-file-name buffer)
+                 (progn
+                   (set-buffer buffer)
+                   (and buffer-offer-save
+                        (> (buffer-size) 0))))
+             (with-current-buffer buffer
+               (let ((proj (muse-project-of-file)))
+                 (and proj (string= (car proj)
+                                    (car project)))))
+             (if (buffer-file-name buffer)
+                 (format "Save file %s? "
+                         (buffer-file-name buffer))
+               (format "Save buffer %s? "
+                       (buffer-name buffer))))))
+     (function
+      (lambda (buffer)
+        (set-buffer buffer)
+        (save-buffer)))
+     (buffer-list)
+     '("buffer" "buffers" "save")
+     (if (boundp 'save-some-buffers-action-alist)
+         save-some-buffers-action-alist))))
 
 (defun muse-project-publish-default (project styles &optional force)
   "Publish the pages of PROJECT that need publishing."
@@ -846,6 +878,9 @@ If FORCE is given, publish the file even if it is up-to-date."
       (funcall custom-set var (car (cdr vars)))
       (setq vars (cdr (cdr vars))))))
 
+(custom-add-option 'muse-before-publish-hook 'muse-project-set-variables)
+(add-to-list 'muse-before-publish-hook 'muse-project-set-variables)
+
 (defun muse-project-delete-output-files (project)
   (interactive
    (list (muse-read-project "Remove all output files for project: " nil t)))
