@@ -1,12 +1,12 @@
 ;;; muse-regexps.el --- define regexps used by Muse
 
-;; Copyright (C) 2004, 2005, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; This file is part of Emacs Muse.  It is not part of GNU Emacs.
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -38,6 +38,9 @@
   "Regular expressions used in publishing and syntax highlighting."
   :group 'muse)
 
+;;; Deal with the lack of character classes for regexps in Emacs21 and
+;;; XEmacs
+
 (defcustom muse-regexp-use-character-classes 'undecided
   "Indicate whether to use extended character classes like [:space:].
 If 'undecided, Muse will use them if your emacs is known to support them.
@@ -137,9 +140,70 @@ the time."
   :options '("[:upper:]" "A-Z")
   :group 'muse-regexp)
 
+;;; Regexps used to define Muse publishing syntax
+
+(defcustom muse-list-item-regexp
+  (concat "^%s\\(\\([^\n" muse-regexp-blank "].*?\\)?::"
+          "\\(?:[" muse-regexp-blank "]+\\|$\\)"
+          "\\|[" muse-regexp-blank "]-[" muse-regexp-blank "]*"
+          "\\|[" muse-regexp-blank "][0-9]+\\.[" muse-regexp-blank "]*\\)")
+  "Regexp used to match the beginning of a list item.
+The '%s' will be replaced with a whitespace regexp when publishing."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-ol-item-regexp (concat "\\`[" muse-regexp-blank "]+[0-9]+\\.")
+  "Regexp used to match an ordered list item."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-ul-item-regexp (concat "\\`[" muse-regexp-blank "]+-")
+  "Regexp used to match an unordered list item."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-dl-term-regexp
+  (concat "[" muse-regexp-blank "]*\\(.+?\\)["
+          muse-regexp-blank "]+::\\(?:[" muse-regexp-blank "]+\\|$\\)")
+  "Regexp used to match a definition list term.
+The first match string must contain the term."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-dl-entry-regexp (concat "\\`[" muse-regexp-blank "]*::")
+  "Regexp used to match a definition list entry."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-table-field-regexp
+  (concat "[" muse-regexp-blank "]+\\(|+\\)\\(?:["
+          muse-regexp-blank "]\\|$\\)")
+  "Regexp used to match table separators when publishing."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-table-line-regexp (concat ".*" muse-table-field-regexp ".*")
+  "Regexp used to match a table line when publishing."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-table-hline-regexp (concat "[" muse-regexp-blank
+                                           "]*|[-+]+|[" muse-regexp-blank
+                                           "]*")
+  "Regexp used to match a horizontal separator line in a table."
+  :type 'regexp
+  :group 'muse-regexp)
+
+(defcustom muse-table-el-border-regexp (concat "[" muse-regexp-blank "]*"
+                                               "\\+\\(-*\\+\\)+"
+                                               "[" muse-regexp-blank "]*")
+  "Regexp used to match the beginning and end of a table.el-style table."
+  :type 'regexp
+  :group 'muse-regexp)
+
 (defcustom muse-tag-regexp
-  (concat "<\\([^/\n" muse-regexp-blank "][^\n" muse-regexp-blank
-          "</>]*\\)\\(\\s-+[^<>]+[^</>]\\)?\\(/\\)?>")
+  (concat "<\\([^/" muse-regexp-blank "\n][^" muse-regexp-blank
+          "</>\n]*\\)\\(\\s-+[^<>\n]+[^</>\n]\\)?\\(/\\)?>")
   "A regexp used to find XML-style tags within a buffer when publishing.
 Group 1 should be the tag name, group 2 the properties, and group
 3 the optional immediate ending slash."
@@ -147,7 +211,7 @@ Group 1 should be the tag name, group 2 the properties, and group
   :group 'muse-regexp)
 
 (defcustom muse-explicit-link-regexp
-  "\\[\\[\\([^][\t\n]+\\)\\]\\(?:\\[\\([^][\n]+\\)\\]\\)?\\]"
+  "\\[\\[\\([^][\n]+\\)\\]\\(?:\\[\\([^][\n]+\\)\\]\\)?\\]"
   "Regexp used to match [[target][description]] links.
 Paren group 1 must match the URL, and paren group 2 the description."
   :type 'regexp
@@ -163,13 +227,20 @@ Paren group 1 is the text to be checked.
 URLs are checked by default.  To get WikiNames, load
 muse-wiki.el.
 
-If you want to match things with spaces in them, you will have to
-modify this."
+This is only used when you are using muse-mode.el, but not
+muse-colors.el.
+
+If the above applies, and you want to match things with spaces in
+them, you will have to modify this."
   :type 'regexp
   :group 'muse-regexp)
 
+;;; Regexps used to determine file types
+
 (defcustom muse-file-regexp
-  "[/?]\\|\\.\\(html?\\|pdf\\|mp3\\|el\\|zip\\|txt\\|tar\\)\\(\\.\\(gz\\|bz2\\)\\)?\\'"
+  (concat "\\`[~/]\\|\\?\\|/\\'\\|\\."
+          "\\(html?\\|pdf\\|mp3\\|el\\|zip\\|txt\\|tar\\)"
+          "\\(\\.\\(gz\\|bz2\\)\\)?\\'")
   "A link matching this regexp will be regarded as a link to a file."
   :type 'regexp
   :group 'muse-regexp)
