@@ -9,7 +9,7 @@
 
 ;; Emacs Muse is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published
-;; by the Free Software Foundation; either version 2, or (at your
+;; by the Free Software Foundation; either version 3, or (at your
 ;; option) any later version.
 
 ;; Emacs Muse is distributed in the hope that it will be useful, but
@@ -67,7 +67,7 @@ page, both when formatting and publishing."
   "Regexp used to match the files in the current project.
 
 This is set by `muse-wiki-update-project-file-regexp' automatically
-when `muse-wiki-martch-all-project-files' is non-nil.")
+when `muse-wiki-match-all-project-files' is non-nil.")
 (make-variable-buffer-local 'muse-wiki-project-file-regexp)
 
 (defun muse-wiki-update-project-file-regexp ()
@@ -117,7 +117,7 @@ they link to the default page of the project that they name."
   :type 'boolean
   :group 'muse-wiki)
 
-(defvar muse-wiki-interwiki-regexp ""
+(defvar muse-wiki-interwiki-regexp nil
   "Regexp that matches all interwiki links.
 
 This is automatically generated by setting `muse-wiki-interwiki-alist'.
@@ -157,7 +157,8 @@ If you want this replacement to happen, you must add
 (defun muse-wiki-update-interwiki-regexp ()
   "Update the value of `muse-wiki-interwiki-regexp' based on
 `muse-wiki-interwiki-alist' and `muse-project-alist'."
-  (when muse-project-alist
+  (if (null muse-project-alist)
+      (setq muse-wiki-interwiki-regexp nil)
     (setq muse-wiki-interwiki-regexp
           (concat "\\<\\(" (regexp-opt (mapcar #'car muse-project-alist))
                   (when muse-wiki-interwiki-alist
@@ -225,7 +226,8 @@ this."
 
 If PAGE is not specified, use the value of :default in PROJECT.
 
-If PROJECT is not specified, default to first project of
+If PROJECT is not specified, default to the current project.  If
+no project is current, use the first project of
 `muse-projects-alist'.
 
 Note that PAGE can have several output directories.  If this is
@@ -235,12 +237,14 @@ style has the same link suffix as the current publishing style,
 use the first style we find."
   (setq project (or (and project
                          (muse-project project))
+                    (muse-project)
                     (car muse-project-alist))
         page (or page (muse-get-keyword :default
                                         (cadr project))))
-  (let* ((page-path (muse-project-page-file page project))
-         (remote-styles (when page-path (muse-project-applicable-styles
-                                         page-path (cddr project))))
+  (let* ((page-path (and muse-project-alist
+                         (muse-project-page-file page project)))
+         (remote-styles (and page-path (muse-project-applicable-styles
+                                        page-path (cddr project))))
          (local-style (muse-project-current-output-style)))
     (cond ((and remote-styles local-style muse-publishing-p)
            (muse-project-resolve-link page local-style remote-styles))
@@ -260,8 +264,9 @@ use the first style we find."
   "If STRING or point has an interwiki link, resolve it to a filename.
 
 Match string 0 is set to the link."
-  (when (if string (string-match muse-wiki-interwiki-regexp string)
-          (looking-at muse-wiki-interwiki-regexp))
+  (when (and muse-wiki-interwiki-regexp
+             (if string (string-match muse-wiki-interwiki-regexp string)
+               (looking-at muse-wiki-interwiki-regexp)))
     (let* ((project (match-string 1 string))
            (subst (cdr (assoc project muse-wiki-interwiki-alist)))
            (word (match-string 3 string))
@@ -281,8 +286,11 @@ Match string 0 is set to the link."
 (defun muse-wiki-handle-explicit-interwiki (&optional string)
   "If STRING or point has an interwiki link, resolve it to a filename."
   (let ((right-pos (if string (length string) (match-end 1))))
-    (when (if string (string-match muse-wiki-interwiki-regexp string)
-            (looking-at muse-wiki-interwiki-regexp))
+    (when (and muse-wiki-interwiki-regexp
+               (if string (string-match muse-wiki-interwiki-regexp string)
+                 (save-restriction
+                   (narrow-to-region (point) right-pos)
+                   (looking-at muse-wiki-interwiki-regexp))))
       (let* ((project (match-string 1 string))
              (subst (cdr (assoc project muse-wiki-interwiki-alist)))
              (anchor (and (match-beginning 4)
